/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <stdbool.h>
/************ Begin %include sections from the grammar ************************/
#line 56 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"

#include "sqlInt.h"
#include "box/fk_constraint.h"

/*
** Disable all error recovery processing in the parser push-down
** automaton.
*/
#define YYNOERRORRECOVERY 1

/*
** Make yytestcase() the same as testcase()
*/
#define yytestcase(X) testcase(X)

/*
** Indicate that sqlParserFree() will never be called with a null
** pointer.
*/
#define YYPARSEFREENEVERNULL 1

/*
** Alternative datatype for the argument to the malloc() routine passed
** into sqlParserAlloc().  The default is size_t.
*/
#define YYMALLOCARGTYPE  u64

/*
 * Stop the parser if an error occurs. This macro adds an
 * additional check that allows the parser to be stopped if any
 * error was noticed.
 */
#define PARSER_ERROR_CHECK && ! pParse->is_aborted

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** Disable lookaside memory allocation for objects that might be
** shared across database connections.
*/
static void disableLookaside(Parse *pParse){
  pParse->disableLookaside++;
  pParse->db->lookaside.bDisable++;
}

#line 479 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"

  /**
   * For a compound SELECT statement, make sure
   * p->pPrior->pNext==p for all elements in the list. And make
   * sure list length does not exceed SQL_LIMIT_COMPOUND_SELECT.
   */
  static void parserDoubleLinkSelect(Parse *pParse, Select *p){
    if( p->pPrior ){
      Select *pNext = 0, *pLoop;
      int mxSelect, cnt = 0;
      for(pLoop=p; pLoop; pNext=pLoop, pLoop=pLoop->pPrior, cnt++){
        pLoop->pNext = pNext;
        pLoop->selFlags |= SF_Compound;
      }
      if( (p->selFlags & SF_MultiValue)==0 && 
        (mxSelect = pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT])>0 &&
        cnt>mxSelect
      ){
         diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of UNION or "\
                  "EXCEPT or INTERSECT operations", cnt,
                  pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT]);
         pParse->is_aborted = true;
      }
    }
  }
#line 964 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"

  /* This is a utility routine used to set the ExprSpan.zStart and
  ** ExprSpan.zEnd values of pOut so that the span covers the complete
  ** range of text beginning with pStart and going to the end of pEnd.
  */
  static void spanSet(ExprSpan *pOut, Token *pStart, Token *pEnd){
    pOut->zStart = pStart->z;
    pOut->zEnd = &pEnd->z[pEnd->n];
  }

  /* Construct a new Expr object from a single identifier.  Use the
  ** new Expr to populate pOut.  Set the span of pOut to be the identifier
  ** that created the expression.
  */
  static void spanExpr(ExprSpan *pOut, Parse *pParse, int op, Token t){
    struct Expr *p = NULL;
    int name_sz = t.n + 1;
    p = sqlDbMallocRawNN(pParse->db, sizeof(Expr) + name_sz);
    if( p ){
      memset(p, 0, sizeof(Expr));
      switch (op) {
      case TK_STRING:
        p->type = FIELD_TYPE_STRING;
        break;
      case TK_BLOB:
        p->type = FIELD_TYPE_VARBINARY;
        break;
      case TK_INTEGER:
        p->type = FIELD_TYPE_INTEGER;
        break;
      case TK_FLOAT:
        p->type = FIELD_TYPE_DOUBLE;
        break;
      case TK_TRUE:
      case TK_FALSE:
      case TK_UNKNOWN:
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      case TK_VARIABLE:
        /*
         * For variables we set BOOLEAN type since
         * unassigned bindings will be replaced
         * with NULL automatically, i.e. without
         * explicit call of sql_bind_*().
         */
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      default:
        p->type = FIELD_TYPE_SCALAR;
        break;
      }
      p->op = (u8)op;
      p->flags = EP_Leaf;
      p->iAgg = -1;
      p->u.zToken = (char*)&p[1];
      if (op != TK_VARIABLE) {
        int rc = sql_normalize_name(p->u.zToken, name_sz, t.z, t.n);
        if (rc > name_sz) {
          name_sz = rc;
          p = sqlDbReallocOrFree(pParse->db, p, sizeof(*p) + name_sz);
          if (p == NULL)
            goto tarantool_error;
          p->u.zToken = (char *) &p[1];
          if (sql_normalize_name(p->u.zToken, name_sz, t.z, t.n) > name_sz)
              unreachable();
        }
      } else {
        memcpy(p->u.zToken, t.z, t.n);
        p->u.zToken[t.n] = 0;
      }
#if SQL_MAX_EXPR_DEPTH>0
      p->nHeight = 1;
#endif  
    }
    pOut->pExpr = p;
    pOut->zStart = t.z;
    pOut->zEnd = &t.z[t.n];
    return;
tarantool_error:
    sqlDbFree(pParse->db, p);
    pParse->is_aborted = true;
  }
#line 1223 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"

  /* This routine constructs a binary expression node out of two ExprSpan
  ** objects and uses the result to populate a new ExprSpan object.
  */
  static void spanBinaryExpr(
    Parse *pParse,      /* The parsing context.  Errors accumulate here */
    int op,             /* The binary operation */
    ExprSpan *pLeft,    /* The left operand, and output */
    ExprSpan *pRight    /* The right operand */
  ){
    pLeft->pExpr = sqlPExpr(pParse, op, pLeft->pExpr, pRight->pExpr);
    pLeft->zEnd = pRight->zEnd;
  }

  /* If doNot is true, then add a TK_NOT Expr-node wrapper around the
  ** outside of *ppExpr.
  */
  static void exprNot(Parse *pParse, int doNot, ExprSpan *pSpan){
    if( doNot ){
      pSpan->pExpr = sqlPExpr(pParse, TK_NOT, pSpan->pExpr, 0);
    }
  }
#line 1297 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"

  /* Construct an expression node for a unary postfix operator
  */
  static void spanUnaryPostfix(
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand, and output */
    Token *pPostOp         /* The operand token for setting the span */
  ){
    pOperand->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOperand->zEnd = &pPostOp->z[pPostOp->n];
  }                           
#line 1318 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"

  /* Construct an expression node for a unary prefix operator
  */
  static void spanUnaryPrefix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPreOp         /* The operand token for setting the span */
  ){
    pOut->zStart = pPreOp->z;
    pOut->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOut->zEnd = pOperand->zEnd;
  }
#line 1520 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"

  /* Add a single new term to an ExprList that is used to store a
  ** list of identifiers.  Report an error if the ID list contains
  ** a COLLATE clause or an ASC or DESC keyword, except ignore the
  ** error while parsing a legacy schema.
  */
  static ExprList *parserAddExprIdListTerm(
    Parse *pParse,
    ExprList *pPrior,
    Token *pIdToken
  ){
    ExprList *p = sql_expr_list_append(pParse->db, pPrior, NULL);
    sqlExprListSetName(pParse, p, pIdToken, 1);
    return p;
  }
#line 1736 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"

  struct alter_args {
    struct SrcList *table_name;
    /** Name of constraint OR new name of table in case of RENAME. */
    struct Token name;
  };
#line 276 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next sections is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    sqlParserTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is sqlParserTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 271
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 76
#define sqlParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlParserTOKENTYPE yy0;
  struct ExprList * yy3;
  struct LimitVal yy4;
  ExprSpan yy82;
  With* yy91;
  Select* yy99;
  int yy112;
  ExprList* yy142;
  struct Expr * yy299;
  struct Token yy307;
  struct SrcList * yy308;
  struct type_def yy330;
  SrcList* yy367;
  enum trim_side_mask yy385;
  IdList* yy420;
  Expr* yy422;
  struct TrigEvent yy450;
  bool yy497;
  TriggerStep* yy527;
  struct alter_args yy530;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlParserARG_SDECL Parse *pParse;
#define sqlParserARG_PDECL ,Parse *pParse
#define sqlParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlParserARG_STORE yypParser->pParse = pParse
#define YYFALLBACK 1
#define YYNSTATE             440
#define YYNRULE              317
#define YY_MAX_SHIFT         439
#define YY_MIN_SHIFTREDUCE   659
#define YY_MAX_SHIFTREDUCE   975
#define YY_MIN_REDUCE        976
#define YY_MAX_REDUCE        1292
#define YY_ERROR_ACTION      1293
#define YY_ACCEPT_ACTION     1294
#define YY_NO_ACTION         1295
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (1637)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    67,   68,  297,  317,  840,  840,  850,  853,   65,   65,
 /*    10 */    66,   66,   66,   66,  773,   64,   64,   64,   64,   63,
 /*    20 */    63,   62,   62,   62,   61,  318,   66,   66,   66,   66,
 /*    30 */    59,   64,   64,   64,   64,   63,   63,   62,   62,   62,
 /*    40 */    61,  318,  965,   50,  965,   48,  966,  966,   67,   68,
 /*    50 */   297,  317,  840,  840,  850,  853,   65,   65,   66,   66,
 /*    60 */    66,   66,  914,   64,   64,   64,   64,   63,   63,   62,
 /*    70 */    62,   62,   61,  318,   60,   58,  193,  310,   67,   68,
 /*    80 */   297,  317,  840,  840,  850,  853,   65,   65,   66,   66,
 /*    90 */    66,   66,  226,   64,   64,   64,   64,   63,   63,   62,
 /*   100 */    62,   62,   61,  318,  967,  759,   54,   64,   64,   64,
 /*   110 */    64,   63,   63,   62,   62,   62,   61,  318,  966,  966,
 /*   120 */   732,   42,  318,   51,   52,  433,  810, 1294,  439,    1,
 /*   130 */    53,  392,  934,   63,   63,   62,   62,   62,   61,  318,
 /*   140 */    69,  424,    3,  104,  104,  905,  810,  914,  319,  319,
 /*   150 */   323,  918,  325,  127,  913,  776,  777,  135,  805,  693,
 /*   160 */   320,  906,  320,  164,  328,  292,  405,  413,  680,  118,
 /*   170 */   295,  907,  723,  660,  322,  320,  967,  758,  805,  724,
 /*   180 */   408,  406,  740,   66,   66,   66,   66,  739,   64,   64,
 /*   190 */    64,   64,   63,   63,   62,   62,   62,   61,  318,  426,
 /*   200 */   809,  809,  811,  812,  813,  814,  807,  928,  929,  930,
 /*   210 */   931,  932,  933,  280,  937,  938,  939,  939,  940,  941,
 /*   220 */   809,  809,  811,  812,  813,  814,  815,  431,  427,  825,
 /*   230 */   826,  827,  969,   20,   67,   68,  297,  317,  840,  840,
 /*   240 */   850,  853,   65,   65,   66,   66,   66,   66,  911,   64,
 /*   250 */    64,   64,   64,   63,   63,   62,   62,   62,   61,  318,
 /*   260 */    67,   68,  297,  317,  840,  840,  850,  853,   65,   65,
 /*   270 */    66,   66,   66,   66,  362,   64,   64,   64,   64,   63,
 /*   280 */    63,   62,   62,   62,   61,  318,   68,  297,  317,  840,
 /*   290 */   840,  850,  853,   65,   65,   66,   66,   66,   66,  916,
 /*   300 */    64,   64,   64,   64,   63,   63,   62,   62,   62,   61,
 /*   310 */   318,   61,  318,  693,   62,   62,   62,   61,  318,   67,
 /*   320 */    68,  297,  317,  840,  840,  850,  853,   65,   65,   66,
 /*   330 */    66,   66,   66,  433,   64,   64,   64,   64,   63,   63,
 /*   340 */    62,   62,   62,   61,  318,  771,  438,  438,  878,  153,
 /*   350 */   288,   85,   85,  371,  132,  677,  677,  683,  688,  382,
 /*   360 */   687,  381,  221,  211,   67,   68,  297,  317,  840,  840,
 /*   370 */   850,  853,   65,   65,   66,   66,   66,   66,  682,   64,
 /*   380 */    64,   64,   64,   63,   63,   62,   62,   62,   61,  318,
 /*   390 */   730,  974,  324,   73,  953,  676,  956,  296,  676,   60,
 /*   400 */    58,  193,  956,  681,  407,   28,  690,  426,  330,   67,
 /*   410 */    68,  297,  317,  840,  840,  850,  853,   65,   65,   66,
 /*   420 */    66,   66,   66,  905,   64,   64,   64,   64,   63,   63,
 /*   430 */    62,   62,   62,   61,  318,  770,  772,  135,  260,  906,
 /*   440 */   176,  175,  126,  915,  291,   60,   58,  193,  831,  907,
 /*   450 */   412,  915,  677,  677,   67,   68,  297,  317,  840,  840,
 /*   460 */   850,  853,   65,   65,   66,   66,   66,   66,  743,   64,
 /*   470 */    64,   64,   64,   63,   63,   62,   62,   62,   61,  318,
 /*   480 */   234,  796,  956,  296,  118,   60,   58,  193,  956,   60,
 /*   490 */    58,  193,  690,  804, 1240, 1240,   60,   58,  193,   67,
 /*   500 */    68,  297,  317,  840,  840,  850,  853,   65,   65,   66,
 /*   510 */    66,   66,   66,  225,   64,   64,   64,   64,   63,   63,
 /*   520 */    62,   62,   62,   61,  318,   67,   68,  297,  317,  840,
 /*   530 */   840,  850,  853,   65,   65,   66,   66,   66,   66,  699,
 /*   540 */    64,   64,   64,   64,   63,   63,   62,   62,   62,   61,
 /*   550 */   318,   67,   68,  297,  317,  840,  840,  850,  853,   65,
 /*   560 */    65,   66,   66,   66,   66,  750,   64,   64,   64,   64,
 /*   570 */    63,   63,   62,   62,   62,   61,  318,  127,  194,  194,
 /*   580 */   717,  377,  375,  381,  362,  393,  951,  168,  717,  292,
 /*   590 */   392,  885,  356,  884,  295,  374,  700,  677,  677,  951,
 /*   600 */    44,  346,  356,   22,   22,  341,   67,   68,  297,  317,
 /*   610 */   840,  840,  850,  853,   65,   65,   66,   66,   66,   66,
 /*   620 */   675,   64,   64,   64,   64,   63,   63,   62,   62,   62,
 /*   630 */    61,  318,  297,  317,  840,  840,  850,  853,   65,   65,
 /*   640 */    66,   66,   66,   66,  799,   64,   64,   64,   64,   63,
 /*   650 */    63,   62,   62,   62,   61,  318,   46,  174,  173,  426,
 /*   660 */   206,  241,  343,  841,  841,  851,  854,  194,  194,  136,
 /*   670 */   212,  262,  261,  251,  433,  399,   71,  233,  389,  392,
 /*   680 */   810,  394,   49,  437,  118,  664,  436,  236,  289,  181,
 /*   690 */   131,  670,   23,   23,  411,  253,  135,  159,    7,  179,
 /*   700 */   191,  756,  965,  351,  965,  675,  299,   55,  331,  430,
 /*   710 */   774,  775,  805,   67,   68,  297,  317,  840,  840,  850,
 /*   720 */   853,   65,   65,   66,   66,   66,   66,   54,   64,   64,
 /*   730 */    64,   64,   63,   63,   62,   62,   62,   61,  318,  348,
 /*   740 */   888,  333,  338,  313,   51,   52,  294, 1009,  426,  233,
 /*   750 */   389,   53,  226,  313,  809,  809,  811,  812,  813,  814,
 /*   760 */   433,  135,  424,    3, 1182,  135,  309,  810,  339,  319,
 /*   770 */   319,  232,  902,  888,  707,  118,  309,  433,   23,   23,
 /*   780 */  1271,   27,  379,  154, 1271,  799,  745,  708,  413,  677,
 /*   790 */   677,  204,  305,  876,  430,   81,   81,  756,  334,  805,
 /*   800 */   354,  713,  252,  353,  156,  128,  262,  261,  311,  677,
 /*   810 */   677,  677,  677,  234,  171,  267,  367,  364,  386,  363,
 /*   820 */  1271,  118,  184,  234,  171,  267,  300,  807,  260,  756,
 /*   830 */   693,  362,  387,  358,  426,  714,  253,  788,  260,  200,
 /*   840 */   808,  809,  809,  811,  812,  813,  814,  815,  431,  427,
 /*   850 */   269,  426,  246,  969,   20,   67,   68,  297,  317,  840,
 /*   860 */   840,  850,  853,   65,   65,   66,   66,   66,   66,  240,
 /*   870 */    64,   64,   64,   64,   63,   63,   62,   62,   62,   61,
 /*   880 */   318,   67,   57,  297,  317,  840,  840,  850,  853,   65,
 /*   890 */    65,   66,   66,   66,   66,   54,   64,   64,   64,   64,
 /*   900 */    63,   63,   62,   62,   62,   61,  318,  271,  135,  245,
 /*   910 */   199,  189,   51,   52,  689,  757,  262,  261,  964,   53,
 /*   920 */   214,   75,  433,  882,  433,  273,  433,  677,  677,  433,
 /*   930 */   424,    3,  799,  135,  433,  810,  135,  319,  319,  278,
 /*   940 */   104,  104,  104,  104,   23,   23,   54,  104,  104,  252,
 /*   950 */   353,  244,   23,   23,    2,  243,  413,  384,  307,  756,
 /*   960 */   677,  677,  756,   51,   52,  744,  402,  805,  757,  340,
 /*   970 */    53,  701,  702,  703,  182,  757,  169,  408,  390,  408,
 /*   980 */   395,  424,    3,  253,  408,  404,  810,  180,  319,  319,
 /*   990 */   965,  388,  965,  735,  735,  807,  426,  756,  426,  207,
 /*  1000 */   426,  433,  208,  426,  722,  722,  276,  413,  426,  809,
 /*  1010 */   809,  811,  812,  813,  814,  815,  431,  427,  805,  104,
 /*  1020 */   104,  969,   20,  161,  433,  803,  433,  182,  757,  433,
 /*  1030 */   740,  186,  433,  720,  720,  739,  422,  908,  192,  191,
 /*  1040 */   226,  432,  104,  104,  104,  104,  807,  104,  104,  756,
 /*  1050 */    82,   82,  433,  677,  677,  803,  408,  425,   10,  433,
 /*  1060 */   809,  809,  811,  812,  813,  814,  815,  431,  427,   54,
 /*  1070 */    25,   25,  969,   20,  756,  426,  433,  102,  102,  408,
 /*  1080 */   385,  314,  902,  308,  400,  118,   51,   52,  756,  877,
 /*  1090 */   342,  347,  803,   53,   77,   77,  239,  433,  426,  756,
 /*  1100 */   426,   39,  876,  426,  424,    3,  426,  257,  803,  810,
 /*  1110 */   354,  319,  319,  844,  726,   87,   87,  278,  876,  917,
 /*  1120 */    54,  302,  396,   41,   74,  922,  426,  433,  725,  352,
 /*  1130 */   413,  920,  277,  426,  433,  306,  803,   51,   52,  248,
 /*  1140 */   912,  805,  910,  952,   53,   88,   88,  676,  433,  871,
 /*  1150 */   426,  316,   89,   89,  433,  424,    3,  433,  303,  433,
 /*  1160 */   810,  921,  319,  319,  256,  397,   90,   90,   43,  807,
 /*  1170 */   335,  426,   91,   91,  304,   26,   26,   78,   78,  433,
 /*  1180 */   414,  413,  360,  809,  809,  811,  812,  813,  814,  815,
 /*  1190 */   431,  427,  805,  433,  880,  969,   20,   80,   80,  301,
 /*  1200 */   433,  426,  315,  900,  729,  326,  118,  118,  426,  228,
 /*  1210 */   249,   92,   92,  415,  418,  336,  118,  195,   93,   93,
 /*  1220 */   807,  419,  426,  423,  118,  361,  118,  337,  426,  242,
 /*  1230 */   433,  426,  791,  426,  809,  809,  811,  812,  813,  814,
 /*  1240 */   815,  431,  427,  433,  691,  691,  969,   20,   94,   94,
 /*  1250 */   433,  344,  433,  426,  433,  202,  801,  433,  776,  777,
 /*  1260 */   224,   24,   24,  185,  433,  266,  433,  426,   95,   95,
 /*  1270 */    96,   96,   97,   97,  426,   98,   98,  433,  265,  994,
 /*  1280 */   433,  250,   99,   99,   83,   83,  899,  433,  355,  177,
 /*  1290 */   178,  433,  224,  706,  705,  100,  100,  433,  101,  101,
 /*  1300 */   433,  897,  359,  433,  426,   84,   84,  357,  896,  123,
 /*  1310 */   123,  224,  365,  366,  255,  124,  124,  426,  125,  125,
 /*  1320 */   686,  108,  108,  433,  426,  433,  426,  433,  426,  870,
 /*  1330 */   433,  426,  372,   41,  433,  669,  228,  433,  426,  433,
 /*  1340 */   426,  103,  103,   86,   86,  111,  111,  259,  105,  105,
 /*  1350 */   433,  426,  112,  112,  426,  110,  110,  122,  122,  264,
 /*  1360 */   433,  426,  433,  716,  433,  426,  433,   41,  117,  117,
 /*  1370 */   764,  426,  433,  275,  426,  816,  816,  426,  116,  116,
 /*  1380 */   115,  115,  113,  113,  114,  114,  802,  746,  715,  737,
 /*  1390 */   107,  107,   35,   45,  766,  875,  874,  426,  224,  426,
 /*  1400 */   228,  426,  433,  279,  426,  285,  948,  433,  426,  433,
 /*  1410 */    12,  426,  433,  426,    9,  170,  678,  667,  666,  668,
 /*  1420 */   109,  109,  298,  119,  426,  106,  106,   76,   76,  160,
 /*  1430 */    79,   79,  151,  238,  426,  129,  426,  140,  426,   39,
 /*  1440 */   426,  142,  787,  345,   30,  144,  426,  209,  883,  350,
 /*  1450 */   146,  370,  147,  210,  162,  217,  155,  247,  798,  368,
 /*  1460 */   218,  120,  219,  258,  901,  711,  312,  378,  696,  380,
 /*  1470 */   697,  685,  121,  263,  710,  383,  426,  684,  398,   38,
 /*  1480 */     8,  426,  858,  426,   47,  754,  426,  268,  417,  755,
 /*  1490 */   270,  421,  753,  272,  429,  752,  936,  274,  736,   70,
 /*  1500 */    40,  401,  227,  403,  281,  435,  949,  286,  293,  284,
 /*  1510 */   282,  283,    4,  287,  945,  235,  237,   11,  662,   72,
 /*  1520 */   321,  919,  947,   13,   29,  196,  137,  327,  329,  197,
 /*  1530 */   198,  201,  138,  332,  881,  172,  205,  203,  139,  797,
 /*  1540 */   141,  133,  145,  727,  886,  143,  224,  148,  149,  895,
 /*  1550 */   150,  971,  349,  152,   31,   32,   33,   34,  134,  898,
 /*  1560 */   894,  215,  213,   21,  216,   14,  254,  163,  672,  369,
 /*  1570 */   220,  157,  373,   15,  265,   16,  376,  177,   36,  709,
 /*  1580 */   830,  222,  178,  130,  734,   37,  391,   45,  828,  856,
 /*  1590 */    17,  187,  760,  738,    6,  845,  188,  190,  223,  158,
 /*  1600 */   765,  869,   41,  410,  857,   18,   19,  855,  818,  904,
 /*  1610 */   416,  903,  183,  409,  926,  165,  229,  927,  860,  166,
 /*  1620 */   420,  859,  167,  231,  829,  230,    5,  434,  935,  428,
 /*  1630 */   817,   56,  673,  290,  663,  659, 1259,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*    10 */    15,   16,   17,   18,  185,   20,   21,   22,   23,   24,
 /*    20 */    25,   26,   27,   28,   29,   30,   15,   16,   17,   18,
 /*    30 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*    40 */    29,   30,   47,  135,   49,  137,   49,   50,    5,    6,
 /*    50 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*    60 */    17,   18,  184,   20,   21,   22,   23,   24,   25,   26,
 /*    70 */    27,   28,   29,   30,  245,  246,  247,   85,    5,    6,
 /*    80 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*    90 */    17,   18,   97,   20,   21,   22,   23,   24,   25,   26,
 /*   100 */    27,   28,   29,   30,  107,  108,    7,   20,   21,   22,
 /*   110 */    23,   24,   25,   26,   27,   28,   29,   30,   49,   50,
 /*   120 */   213,   48,   30,   24,   25,  170,   47,  164,  165,  166,
 /*   130 */    31,  224,   75,   24,   25,   26,   27,   28,   29,   30,
 /*   140 */    67,   42,   43,  188,  189,   35,   47,  269,   49,   50,
 /*   150 */    80,   81,   82,  170,  170,  112,  113,   45,   79,   84,
 /*   160 */   177,   51,  179,  180,   94,  182,  211,   68,  188,  214,
 /*   170 */   187,   61,   62,    1,    2,  192,  107,  108,   79,   69,
 /*   180 */   225,  226,   99,   15,   16,   17,   18,  104,   20,   21,
 /*   190 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  244,
 /*   200 */   121,  122,  123,  124,  125,  126,  107,  150,  151,  152,
 /*   210 */   153,  154,  155,  156,  157,  158,  159,  160,  161,  162,
 /*   220 */   121,  122,  123,  124,  125,  126,  127,  128,  129,  130,
 /*   230 */   131,  132,  133,  134,    5,    6,    7,    8,    9,   10,
 /*   240 */    11,   12,   13,   14,   15,   16,   17,   18,  264,   20,
 /*   250 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   260 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   270 */    15,   16,   17,   18,  170,   20,   21,   22,   23,   24,
 /*   280 */    25,   26,   27,   28,   29,   30,    6,    7,    8,    9,
 /*   290 */    10,   11,   12,   13,   14,   15,   16,   17,   18,   44,
 /*   300 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   310 */    30,   29,   30,   84,   26,   27,   28,   29,   30,    5,
 /*   320 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   330 */    16,   17,   18,  170,   20,   21,   22,   23,   24,   25,
 /*   340 */    26,   27,   28,   29,   30,  191,  167,  168,  188,   43,
 /*   350 */   171,  188,  189,    7,  175,   49,   50,  188,   44,   80,
 /*   360 */    81,   82,   83,  259,    5,    6,    7,    8,    9,   10,
 /*   370 */    11,   12,   13,   14,   15,   16,   17,   18,  188,   20,
 /*   380 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   390 */   211,  181,  266,  214,  181,  185,  186,  187,  185,  245,
 /*   400 */   246,  247,  192,   44,  241,  242,  196,  244,  237,    5,
 /*   410 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   420 */    16,   17,   18,   35,   20,   21,   22,   23,   24,   25,
 /*   430 */    26,   27,   28,   29,   30,  191,  185,   45,   92,   51,
 /*   440 */   261,  262,  263,  196,  265,  245,  246,  247,   44,   61,
 /*   450 */    62,  204,   49,   50,    5,    6,    7,    8,    9,   10,
 /*   460 */    11,   12,   13,   14,   15,   16,   17,   18,  228,   20,
 /*   470 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   480 */    77,  211,  186,  187,  214,  245,  246,  247,  192,  245,
 /*   490 */   246,  247,  196,   44,  102,  103,  245,  246,  247,    5,
 /*   500 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   510 */    16,   17,   18,  228,   20,   21,   22,   23,   24,   25,
 /*   520 */    26,   27,   28,   29,   30,    5,    6,    7,    8,    9,
 /*   530 */    10,   11,   12,   13,   14,   15,   16,   17,   18,  199,
 /*   540 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   550 */    30,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   560 */    14,   15,   16,   17,   18,  231,   20,   21,   22,   23,
 /*   570 */    24,   25,   26,   27,   28,   29,   30,  170,  212,  213,
 /*   580 */   196,   80,   81,   82,  170,  170,  179,  180,  204,  182,
 /*   590 */   224,   54,  170,   56,  187,   94,  199,   49,   50,  192,
 /*   600 */   106,   64,  170,  188,  189,  239,    5,    6,    7,    8,
 /*   610 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   620 */   184,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   630 */    29,   30,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   640 */    15,   16,   17,   18,   69,   20,   21,   22,   23,   24,
 /*   650 */    25,   26,   27,   28,   29,   30,  136,   24,   25,  244,
 /*   660 */   238,   86,   87,    9,   10,   11,   12,  212,  213,  195,
 /*   670 */   238,  197,  198,  259,  170,  235,   43,  102,  103,  224,
 /*   680 */    47,  211,  136,   32,  214,   34,   35,   36,   37,  235,
 /*   690 */    53,   40,  188,  189,  208,  120,   45,  149,   43,  229,
 /*   700 */   230,  170,   47,  255,   49,  269,  202,  106,   71,  184,
 /*   710 */    73,   74,   79,    5,    6,    7,    8,    9,   10,   11,
 /*   720 */    12,   13,   14,   15,   16,   17,   18,    7,   20,   21,
 /*   730 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   86,
 /*   740 */    87,  210,   91,    7,   24,   25,   95,    1,  244,  102,
 /*   750 */   103,   31,   97,    7,  121,  122,  123,  124,  125,  126,
 /*   760 */   170,   45,   42,   43,   44,   45,   30,   47,  117,   49,
 /*   770 */    50,  217,  211,  120,   57,  214,   30,  170,  188,  189,
 /*   780 */    44,  227,   65,   43,   48,   69,   26,   70,   68,   49,
 /*   790 */    50,  140,  202,  170,  269,  188,  189,  170,  147,   79,
 /*   800 */   239,   59,   86,   87,  195,   97,  197,  198,   91,   49,
 /*   810 */    50,   49,   50,   77,   78,   79,  251,  252,  211,  258,
 /*   820 */    84,  214,  254,   77,   78,   79,  203,  107,   92,  170,
 /*   830 */    84,  170,  225,  170,  244,   93,  120,  210,   92,   77,
 /*   840 */   170,  121,  122,  123,  124,  125,  126,  127,  128,  129,
 /*   850 */   228,  244,   39,  133,  134,    5,    6,    7,    8,    9,
 /*   860 */    10,   11,   12,   13,   14,   15,   16,   17,   18,  210,
 /*   870 */    20,   21,   22,   23,   24,   25,   26,   27,   28,   29,
 /*   880 */    30,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   890 */    14,   15,   16,   17,   18,    7,   20,   21,   22,   23,
 /*   900 */    24,   25,   26,   27,   28,   29,   30,  228,   45,   96,
 /*   910 */   148,   44,   24,   25,  195,   48,  197,  198,   48,   31,
 /*   920 */   259,   43,  170,   60,  170,  228,  170,   49,   50,  170,
 /*   930 */    42,   43,   69,   45,  170,   47,   45,   49,   50,  170,
 /*   940 */   188,  189,  188,  189,  188,  189,    7,  188,  189,   86,
 /*   950 */    87,  138,  188,  189,   43,  142,   68,   26,  202,  170,
 /*   960 */    49,   50,  170,   24,   25,   26,  202,   79,   48,   78,
 /*   970 */    31,   88,   89,   90,  107,  108,  106,  225,  226,  225,
 /*   980 */   226,   42,   43,  120,  225,  226,   47,  170,   49,   50,
 /*   990 */    47,   98,   49,  100,  101,  107,  244,  170,  244,  210,
 /*  1000 */   244,  170,  210,  244,  207,  208,  170,   68,  244,  121,
 /*  1010 */   122,  123,  124,  125,  126,  127,  128,  129,   79,  188,
 /*  1020 */   189,  133,  134,  215,  170,  170,  170,  107,  108,  170,
 /*  1030 */    99,   48,  170,  207,  208,  104,  267,  210,  229,  230,
 /*  1040 */    97,    7,  188,  189,  188,  189,  107,  188,  189,  170,
 /*  1050 */   188,  189,  170,   49,   50,  170,  225,  226,  216,  170,
 /*  1060 */   121,  122,  123,  124,  125,  126,  127,  128,  129,    7,
 /*  1070 */   188,  189,  133,  134,  170,  244,  170,  188,  189,  225,
 /*  1080 */   226,  225,  211,  201,  225,  214,   24,   25,  170,  210,
 /*  1090 */   232,  236,  170,   31,  188,  189,  170,  170,  244,  170,
 /*  1100 */   244,  118,  170,  244,   42,   43,  244,   39,  170,   47,
 /*  1110 */   239,   49,   50,   79,  210,  188,  189,  170,  170,   44,
 /*  1120 */     7,  236,    7,   48,  253,  170,  244,  170,  210,  258,
 /*  1130 */    68,  170,  243,  244,  170,  203,  170,   24,   25,  210,
 /*  1140 */   170,   79,  170,  181,   31,  188,  189,  185,  170,   81,
 /*  1150 */   244,  203,  188,  189,  170,   42,   43,  170,  236,  170,
 /*  1160 */    47,  170,   49,   50,   96,   50,  188,  189,  106,  107,
 /*  1170 */   170,  244,  188,  189,  236,  188,  189,  188,  189,  170,
 /*  1180 */   250,   68,    7,  121,  122,  123,  124,  125,  126,  127,
 /*  1190 */   128,  129,   79,  170,   44,  133,  134,  188,  189,  170,
 /*  1200 */   170,  244,  236,  211,  211,   44,  214,  214,  244,   48,
 /*  1210 */   142,  188,  189,  211,  267,  170,  214,   43,  188,  189,
 /*  1220 */   107,  211,  244,  211,  214,   50,  214,  170,  244,  232,
 /*  1230 */   170,  244,  219,  244,  121,  122,  123,  124,  125,  126,
 /*  1240 */   127,  128,  129,  170,   49,   50,  133,  134,  188,  189,
 /*  1250 */   170,  170,  170,  244,  170,  105,   44,  170,  112,  113,
 /*  1260 */    48,  188,  189,  170,  170,   79,  170,  244,  188,  189,
 /*  1270 */   188,  189,  188,  189,  244,  188,  189,  170,   92,  105,
 /*  1280 */   170,  260,  188,  189,  188,  189,  219,  170,   44,   86,
 /*  1290 */    87,  170,   48,   78,   79,  188,  189,  170,  188,  189,
 /*  1300 */   170,  170,  260,  170,  244,  188,  189,   44,  170,  188,
 /*  1310 */   189,   48,  170,  170,  170,  188,  189,  244,  188,  189,
 /*  1320 */   191,  188,  189,  170,  244,  170,  244,  170,  244,   44,
 /*  1330 */   170,  244,   44,   48,  170,  170,   48,  170,  244,  170,
 /*  1340 */   244,  188,  189,  188,  189,  188,  189,  170,  188,  189,
 /*  1350 */   170,  244,  188,  189,  244,  188,  189,  188,  189,  170,
 /*  1360 */   170,  244,  170,   44,  170,  244,  170,   48,  188,  189,
 /*  1370 */   170,  244,  170,  232,  244,   49,   50,  244,  188,  189,
 /*  1380 */   188,  189,  188,  189,  188,  189,  170,  170,   44,   44,
 /*  1390 */   188,  189,   48,   48,   44,  170,   44,  244,   48,  244,
 /*  1400 */    48,  244,  170,  170,  244,  218,   44,  170,  244,  170,
 /*  1410 */    48,  244,  170,  244,  216,  216,  170,  170,  170,  170,
 /*  1420 */   188,  189,    9,  194,  244,  188,  189,  188,  189,   43,
 /*  1430 */   188,  189,   43,  193,  244,    5,  244,  240,  244,  118,
 /*  1440 */   244,  206,  219,   41,  135,  209,  244,  209,  257,  144,
 /*  1450 */   209,   41,  209,  176,  240,  176,  206,  256,  206,  193,
 /*  1460 */   176,  194,  176,  193,  219,  200,   63,   85,  197,   85,
 /*  1470 */   198,  190,  194,  193,  200,   85,  244,  190,  110,   85,
 /*  1480 */    43,  244,  248,  244,  135,  234,  244,  233,  193,  234,
 /*  1490 */   233,  193,  234,  233,   43,  234,  268,  233,  223,  116,
 /*  1500 */   115,  114,  249,  111,  222,   46,  178,   45,  173,  219,
 /*  1510 */   221,  220,   43,  172,   36,  169,  169,  183,    4,  183,
 /*  1520 */     3,   66,  174,   43,   43,   83,   43,   66,   82,   77,
 /*  1530 */    38,   77,   39,   95,   44,   14,  139,   43,   39,  103,
 /*  1540 */   119,   91,   85,   42,  143,  106,   48,  143,   85,    1,
 /*  1550 */   106,  146,  145,  119,   14,   14,   14,   14,   91,   50,
 /*  1560 */     1,  105,  109,  141,   85,   43,  138,   97,   42,    7,
 /*  1570 */    83,   43,   66,   43,   92,   43,   66,   86,   43,   52,
 /*  1580 */    44,   66,   87,   58,   99,   48,   48,   48,   44,   44,
 /*  1590 */    43,  105,  108,   44,   43,   79,   44,   44,  109,   43,
 /*  1600 */    50,   44,   48,   48,   44,  109,  109,   44,   44,   44,
 /*  1610 */    97,   44,   43,   47,   44,   43,   48,   44,   60,   43,
 /*  1620 */    97,   44,   43,  105,   44,   43,   43,   14,   44,  126,
 /*  1630 */    44,   43,   47,   38,   33,    1,    0,
};
#define YY_SHIFT_USE_DFLT (1637)
#define YY_SHIFT_COUNT    (439)
#define YY_SHIFT_MIN      (-92)
#define YY_SHIFT_MAX      (1636)
static const short yy_shift_ofst[] = {
 /*     0 */   172,  651,  720,  888,  403,   99, 1113, 1113, 1113, 1113,
 /*    10 */  1113,  746,  403, 1113, 1113, 1113, 1113, 1113, 1113, 1113,
 /*    20 */  1113,  716,   -5,   43,   43,  229,  229,  939, 1062, 1113,
 /*    30 */  1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113,
 /*    40 */  1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113,
 /*    50 */  1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113,
 /*    60 */  1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113, 1113,
 /*    70 */  1113, 1113,  736,  575,  863,  392,   73,  255,  314,  359,
 /*    80 */   404,  449,  494,  520,  546,  601,  708,  850,  850,  850,
 /*    90 */   850,  850,  850,  850,  850,  850,  850,  850,  850,  850,
 /*   100 */   850,  850,  850,  850,  850,  876,  850,  280,  625,  625,
 /*   110 */    11,  168,  168,  168,   87,  109,  288,  282,  647,   -8,
 /*   120 */    -8,   -8,   92, 1637, 1637, 1637,   57,   57,   57,  110,
 /*   130 */   110,  762, 1068,  306,  306,  548,  346, 1004, 1004, 1004,
 /*   140 */   891, 1004, 1004, 1004, 1004, 1004, 1004, 1004, 1004, 1004,
 /*   150 */  1004, 1004, 1004, 1004, 1004, 1004,  346, 1004, 1004, 1004,
 /*   160 */  1004,  647,  112,  112,   75,  112,  112,  112,   75, 1637,
 /*   170 */  1637,  633,   79,   79,   79,   70,  637,  717,  717,  867,
 /*   180 */   655,   -3,   69,  388,  653,  537,  740,  760,  943,  943,
 /*   190 */   943,  878,  920,  911,  893,  931, 1004, 1004, 1004, 1004,
 /*   200 */  1004, 1004, 1004, 1004, 1004, 1004,  983, 1115, 1115, 1004,
 /*   210 */  1004, 1175,  983, 1004, 1175, 1004, 1004, 1004, 1004, 1004,
 /*   220 */  1004, 1004, 1146, 1004, 1004, 1115, 1004,  -92, 1004, 1004,
 /*   230 */    83, 1004,  870,   83, 1004, 1004, 1004, 1004, 1413, 1386,
 /*   240 */  1389, 1430, 1321, 1402, 1402, 1402, 1402, 1309, 1305, 1410,
 /*   250 */  1321, 1389, 1430, 1430, 1410, 1386, 1410, 1410, 1413, 1386,
 /*   260 */  1403, 1382, 1384, 1413, 1386, 1403, 1390, 1390, 1368, 1394,
 /*   270 */  1368, 1394, 1368, 1394, 1368, 1394, 1437, 1349, 1386, 1386,
 /*   280 */  1451, 1383, 1392, 1385, 1387, 1321, 1459, 1462, 1469, 1478,
 /*   290 */  1478, 1637, 1637, 1637,  813,  501,  279,  654,  883, 1075,
 /*   300 */  1161, 1150, 1212, 1244, 1263, 1285, 1288, 1319, 1344, 1195,
 /*   310 */  1203, 1215,  742, 1186, 1345, 1350, 1352, 1034, 1326, 1174,
 /*   320 */  1362, 1514, 1517, 1455, 1480, 1481, 1442, 1483, 1461, 1452,
 /*   330 */  1446, 1492, 1454, 1438, 1493, 1490, 1494, 1521, 1397, 1499,
 /*   340 */  1436, 1421, 1450, 1439, 1457, 1501, 1401, 1498, 1404, 1405,
 /*   350 */  1407, 1463, 1548, 1444, 1434, 1540, 1541, 1542, 1543, 1467,
 /*   360 */  1509, 1453, 1456, 1559, 1422, 1522, 1479, 1428, 1470, 1526,
 /*   370 */  1562, 1482, 1487, 1528, 1506, 1530, 1532, 1510, 1491, 1527,
 /*   380 */  1495, 1535, 1515, 1525, 1536, 1544, 1545, 1537, 1485, 1547,
 /*   390 */  1549, 1551, 1538, 1486, 1552, 1553, 1550, 1489, 1556, 1484,
 /*   400 */  1539, 1496, 1554, 1497, 1557, 1560, 1563, 1564, 1539, 1565,
 /*   410 */  1566, 1555, 1567, 1569, 1558, 1570, 1572, 1513, 1568, 1573,
 /*   420 */  1576, 1523, 1568, 1577, 1579, 1580, 1582, 1583, 1584, 1503,
 /*   430 */  1586, 1588, 1516, 1518, 1585, 1613, 1595, 1601, 1634, 1636,
};
#define YY_REDUCE_USE_DFLT (-172)
#define YY_REDUCE_COUNT (293)
#define YY_REDUCE_MIN   (-171)
#define YY_REDUCE_MAX   (1348)
static const short yy_reduce_ofst[] = {
 /*     0 */   -37,  179,  -45,  607,  -17,  163,  752,  754,  759,  831,
 /*    10 */   854,  210,  407,  504,  590,  756,  882,  856,  859,  764,
 /*    20 */   889,  871,  240,  154,  244, -171,  251,  415,  862,  906,
 /*    30 */   927,  957,  964,  978,  984,  987,  989, 1009, 1023, 1030,
 /*    40 */  1060, 1073, 1080, 1082, 1084, 1087, 1094, 1096, 1107, 1110,
 /*    50 */  1117, 1121, 1127, 1130, 1133, 1153, 1155, 1157, 1160, 1164,
 /*    60 */  1167, 1169, 1180, 1190, 1192, 1194, 1196, 1202, 1232, 1237,
 /*    70 */  1239, 1242,  296,  366,  561,  470,  200,  200,  200,  200,
 /*    80 */   200,  200,  200,  200,  200,  200,  200,  200,  200,  200,
 /*    90 */   200,  200,  200,  200,  200,  200,  200,  200,  200,  200,
 /*   100 */   200,  200,  200,  200,  200,  200,  200,  200,  200,  200,
 /*   110 */   200,  200,  200,  200,  200,  200,  200,  200,  455,  474,
 /*   120 */   609,  719,  200,  200,  200,  200, -122,  436,  525,  797,
 /*   130 */   826,  -16,  565,  422,  432,  769,  247,  623,  531,  627,
 /*   140 */   270,  659,  789,  792,  827,  879,  904,  918,  855,  929,
 /*   150 */   104,  885,  414,  922,  938,  661,  384,  932,  966,  947,
 /*   160 */   948,  -93,  992,  993,  213, 1002, 1010, 1012,  962,  809,
 /*   170 */   554,  -20,  160,  169,  190,  126,  171,  340,  397,  334,
 /*   180 */   285,  440,  454,  486,  448,  568,  663,  670,  622,  679,
 /*   190 */   697,  817,  334,  836,  808,  842,  926,  955,  961,  970,
 /*   200 */   972,  991, 1000, 1029, 1045, 1057, 1013,  858,  997, 1081,
 /*   210 */  1093, 1021, 1067, 1131, 1042, 1138, 1142, 1143, 1144, 1165,
 /*   220 */  1177, 1189, 1129, 1200, 1216, 1141, 1217,  930, 1225, 1233,
 /*   230 */  1198,  670, 1187, 1199, 1246, 1247, 1248, 1249, 1229, 1240,
 /*   240 */  1197, 1235, 1223, 1236, 1238, 1241, 1243, 1191, 1201, 1277,
 /*   250 */  1245, 1214, 1250, 1252, 1279, 1266, 1284, 1286, 1267, 1270,
 /*   260 */  1265, 1271, 1272, 1278, 1280, 1274, 1281, 1287, 1251, 1254,
 /*   270 */  1255, 1257, 1258, 1260, 1261, 1264, 1234, 1253, 1295, 1298,
 /*   280 */  1228, 1275, 1282, 1289, 1291, 1290, 1328, 1335, 1341, 1346,
 /*   290 */  1347, 1334, 1336, 1348,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1260, 1240, 1240, 1240,  996, 1293, 1182, 1182, 1182, 1182,
 /*    10 */  1182,  996,  996, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*    20 */  1140, 1240, 1064, 1095, 1095, 1009, 1009, 1293, 1293, 1293,
 /*    30 */  1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*    40 */  1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*    50 */  1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*    60 */  1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*    70 */  1293, 1293,  996, 1293, 1240, 1068, 1101, 1293, 1293, 1293,
 /*    80 */  1183, 1184, 1293, 1293, 1293, 1139, 1293, 1210, 1112, 1111,
 /*    90 */  1110, 1109, 1078, 1107, 1099, 1103, 1137, 1136, 1183, 1179,
 /*   100 */  1180, 1178, 1141, 1138, 1184, 1293, 1102, 1150, 1163, 1149,
 /*   110 */  1159, 1169, 1160, 1152, 1151, 1153, 1154, 1155, 1293, 1015,
 /*   120 */  1015, 1015, 1156, 1166, 1165, 1164, 1293, 1293, 1293, 1293,
 /*   130 */  1293, 1293, 1189, 1293, 1293, 1293, 1035, 1293, 1293, 1293,
 /*   140 */  1240, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*   150 */  1293, 1293, 1293, 1293, 1293, 1293, 1035, 1293, 1293, 1293,
 /*   160 */  1293, 1293, 1240, 1240, 1009, 1240, 1240, 1240, 1009, 1068,
 /*   170 */  1059, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*   180 */  1064, 1293, 1293, 1293, 1293, 1204, 1293, 1293, 1064, 1064,
 /*   190 */  1064, 1293, 1066, 1293, 1048, 1058, 1293, 1293, 1293, 1293,
 /*   200 */  1293, 1293, 1293, 1293, 1293, 1293, 1106, 1080, 1080, 1293,
 /*   210 */  1293, 1290, 1106, 1293, 1290, 1293, 1293, 1293, 1293, 1293,
 /*   220 */  1293, 1293, 1095, 1293, 1293, 1080, 1293, 1181, 1293, 1293,
 /*   230 */  1058, 1293, 1065, 1058, 1293, 1293, 1293, 1293, 1021, 1190,
 /*   240 */  1117, 1038, 1106, 1045, 1045, 1045, 1045, 1209, 1208,  988,
 /*   250 */  1106, 1117, 1038, 1038,  988, 1190,  988,  988, 1021, 1190,
 /*   260 */  1029, 1012, 1011, 1021, 1190, 1029, 1036, 1036, 1084, 1079,
 /*   270 */  1084, 1079, 1084, 1079, 1084, 1079, 1185, 1293, 1190, 1190,
 /*   280 */  1293, 1100, 1085, 1098, 1096, 1106, 1293, 1267, 1293, 1263,
 /*   290 */  1263, 1274, 1274,  991, 1293, 1293, 1293, 1293, 1293, 1293,
 /*   300 */  1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*   310 */  1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1123,
 /*   320 */  1293, 1293,  978, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*   330 */  1293, 1293, 1293, 1226, 1293, 1293, 1196, 1293, 1293, 1293,
 /*   340 */  1293, 1293, 1293, 1293, 1293, 1293, 1293, 1207, 1206, 1293,
 /*   350 */  1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*   360 */  1293, 1293, 1289, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*   370 */  1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*   380 */  1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1050, 1293,
 /*   390 */  1293, 1293, 1280, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*   400 */  1097, 1293, 1086, 1293, 1293, 1293, 1293, 1293, 1287, 1293,
 /*   410 */  1293, 1293, 1293, 1293, 1293, 1293, 1293, 1293, 1242, 1293,
 /*   420 */  1293, 1293, 1241, 1293, 1293, 1293, 1293, 1293, 1293, 1293,
 /*   430 */  1293, 1293, 1293, 1293, 1293, 1293,  982, 1293, 1293, 1293,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
    0,  /*    EXPLAIN => nothing */
   49,  /*      QUERY => ID */
   49,  /*       PLAN => ID */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*        NOT => nothing */
    0,  /*         IS => nothing */
   49,  /*      MATCH => ID */
    0,  /*    LIKE_KW => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*      START => nothing */
    0,  /* TRANSACTION => nothing */
    0,  /*     COMMIT => nothing */
    0,  /*   ROLLBACK => nothing */
    0,  /*  SAVEPOINT => nothing */
   49,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   49,  /*         IF => ID */
    0,  /*     EXISTS => nothing */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*       WITH => nothing */
   49,  /*     ENGINE => ID */
    0,  /*     STRING => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   49,  /*      ABORT => ID */
   49,  /*     ACTION => ID */
   49,  /*        ADD => ID */
   49,  /*      AFTER => ID */
   49,  /* AUTOINCREMENT => ID */
   49,  /*     BEFORE => ID */
   49,  /*    CASCADE => ID */
   49,  /*   CONFLICT => ID */
   49,  /*   DEFERRED => ID */
   49,  /*        END => ID */
   49,  /*       FAIL => ID */
   49,  /*     IGNORE => ID */
   49,  /*  INITIALLY => ID */
   49,  /*    INSTEAD => ID */
   49,  /*         NO => ID */
   49,  /*        KEY => ID */
   49,  /*     OFFSET => ID */
   49,  /*      RAISE => ID */
   49,  /*    REPLACE => ID */
   49,  /*   RESTRICT => ID */
   49,  /*     RENAME => ID */
   49,  /*   CTIME_KW => ID */
   49,  /*     ENABLE => ID */
   49,  /*    DISABLE => ID */
   49,  /*       UUID => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  bool is_fallback_failed;      /* Shows if fallback failed or not */
  sqlParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "OR",            "AND",           "NOT",         
  "IS",            "MATCH",         "LIKE_KW",       "BETWEEN",     
  "IN",            "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "BITNOT",      
  "START",         "TRANSACTION",   "COMMIT",        "ROLLBACK",    
  "SAVEPOINT",     "RELEASE",       "TO",            "TABLE",       
  "CREATE",        "IF",            "EXISTS",        "LP",          
  "RP",            "WITH",          "ENGINE",        "STRING",      
  "COMMA",         "ID",            "INDEXED",       "ABORT",       
  "ACTION",        "ADD",           "AFTER",         "AUTOINCREMENT",
  "BEFORE",        "CASCADE",       "CONFLICT",      "DEFERRED",    
  "END",           "FAIL",          "IGNORE",        "INITIALLY",   
  "INSTEAD",       "NO",            "KEY",           "OFFSET",      
  "RAISE",         "REPLACE",       "RESTRICT",      "RENAME",      
  "CTIME_KW",      "ENABLE",        "DISABLE",       "UUID",        
  "ANY",           "CONSTRAINT",    "DEFAULT",       "NULL",        
  "PRIMARY",       "UNIQUE",        "CHECK",         "REFERENCES",  
  "AUTOINCR",      "ON",            "UPDATE",        "DELETE",      
  "SIMPLE",        "PARTIAL",       "FULL",          "SET",         
  "DEFERRABLE",    "IMMEDIATE",     "FOREIGN",       "DROP",        
  "VIEW",          "AS",            "UNION",         "ALL",         
  "EXCEPT",        "INTERSECT",     "SELECT",        "VALUES",      
  "DISTINCT",      "DOT",           "FROM",          "JOIN_KW",     
  "JOIN",          "BY",            "USING",         "ORDER",       
  "ASC",           "DESC",          "GROUP",         "HAVING",      
  "LIMIT",         "TRUNCATE",      "WHERE",         "INTO",        
  "INSERT",        "FLOAT",         "BLOB",          "FALSE",       
  "TRUE",          "UNKNOWN",       "INTEGER",       "VARIABLE",    
  "CAST",          "TRIM",          "LEADING",       "TRAILING",    
  "BOTH",          "CHAR",          "CASE",          "WHEN",        
  "THEN",          "ELSE",          "INDEX",         "SESSION",     
  "PRAGMA",        "BEGIN",         "TRIGGER",       "OF",          
  "FOR",           "EACH",          "ROW",           "ALTER",       
  "COLUMN",        "RECURSIVE",     "TEXT",          "STRING_KW",   
  "SCALAR",        "BOOL",          "BOOLEAN",       "VARBINARY",   
  "VARCHAR",       "NUMBER",        "DOUBLE",        "INT",         
  "INTEGER_KW",    "UNSIGNED",      "DECIMAL",       "error",       
  "input",         "ecmd",          "explain",       "cmdx",        
  "cmd",           "savepoint_opt",  "nm",            "create_table",
  "create_table_args",  "with_opts",     "create_table_end",  "createkw",    
  "ifnotexists",   "columnlist",    "engine_opts",   "tcons",       
  "column_def",    "create_column_end",  "column_name_and_type",  "carglist",    
  "typedef",       "autoinc",       "ccons",         "cconsname",   
  "term",          "expr",          "onconf",        "sortorder",   
  "check_constraint_def",  "eidlist_opt",   "matcharg",      "refargs",     
  "defer_subclause",  "refact_update",  "refact_delete",  "refact",      
  "init_deferred_pred_opt",  "col_list_with_autoinc",  "sortlist",      "eidlist",     
  "defer_subclause_opt",  "index_onconf",  "orconf",        "resolvetype", 
  "raisetype",     "ifexists",      "fullname",      "select",      
  "selectnowith",  "oneselect",     "with",          "multiselect_op",
  "distinct",      "selcollist",    "from",          "where_opt",   
  "groupby_opt",   "having_opt",    "orderby_opt",   "limit_opt",   
  "values",        "nexprlist",     "exprlist",      "sclp",        
  "as",            "seltablist",    "stl_prefix",    "joinop",      
  "indexed_opt",   "on_opt",        "using_opt",     "join_nm",     
  "idlist",        "enable",        "setlist",       "insert_cmd",  
  "idlist_opt",    "trim_operands",  "trim_specification",  "expr_optional",
  "type_func",     "likeop",        "between_op",    "in_op",       
  "paren_exprlist",  "case_exprlist",  "case_else",     "uniqueflag",  
  "trigger_decl",  "trigger_cmd_list",  "trigger_time",  "trigger_event",
  "foreach_clause",  "when_clause",   "trigger_cmd",   "trnm",        
  "tridxby",       "alter_table_start",  "alter_add_constraint",  "alter_add_column",
  "column_name",   "alter_column_def",  "unique_spec",   "wqlist",      
  "char_len",      "number_typedef",
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "ecmd ::= explain cmdx SEMI",
 /*   1 */ "ecmd ::= SEMI",
 /*   2 */ "explain ::= EXPLAIN",
 /*   3 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   4 */ "cmd ::= START TRANSACTION",
 /*   5 */ "cmd ::= COMMIT",
 /*   6 */ "cmd ::= ROLLBACK",
 /*   7 */ "cmd ::= SAVEPOINT nm",
 /*   8 */ "cmd ::= RELEASE savepoint_opt nm",
 /*   9 */ "cmd ::= ROLLBACK TO savepoint_opt nm",
 /*  10 */ "create_table ::= createkw TABLE ifnotexists nm",
 /*  11 */ "createkw ::= CREATE",
 /*  12 */ "ifnotexists ::=",
 /*  13 */ "ifnotexists ::= IF NOT EXISTS",
 /*  14 */ "engine_opts ::= ENGINE EQ STRING",
 /*  15 */ "create_table_end ::=",
 /*  16 */ "column_name_and_type ::= nm typedef",
 /*  17 */ "create_column_end ::= autoinc",
 /*  18 */ "nm ::= ID|INDEXED",
 /*  19 */ "cconsname ::= CONSTRAINT nm",
 /*  20 */ "cconsname ::=",
 /*  21 */ "ccons ::= DEFAULT term",
 /*  22 */ "ccons ::= DEFAULT LP expr RP",
 /*  23 */ "ccons ::= DEFAULT PLUS term",
 /*  24 */ "ccons ::= DEFAULT MINUS term",
 /*  25 */ "ccons ::= NULL onconf",
 /*  26 */ "ccons ::= NOT NULL onconf",
 /*  27 */ "ccons ::= cconsname PRIMARY KEY sortorder",
 /*  28 */ "ccons ::= cconsname UNIQUE",
 /*  29 */ "check_constraint_def ::= cconsname CHECK LP expr RP",
 /*  30 */ "ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs",
 /*  31 */ "ccons ::= defer_subclause",
 /*  32 */ "ccons ::= COLLATE ID|INDEXED",
 /*  33 */ "autoinc ::=",
 /*  34 */ "autoinc ::= AUTOINCR",
 /*  35 */ "refargs ::= refact_update",
 /*  36 */ "refargs ::= refact_delete",
 /*  37 */ "refargs ::= refact_delete refact_update",
 /*  38 */ "refargs ::= refact_update refact_delete",
 /*  39 */ "refargs ::=",
 /*  40 */ "refact_update ::= ON UPDATE refact",
 /*  41 */ "refact_delete ::= ON DELETE refact",
 /*  42 */ "matcharg ::= MATCH SIMPLE",
 /*  43 */ "matcharg ::= MATCH PARTIAL",
 /*  44 */ "matcharg ::= MATCH FULL",
 /*  45 */ "matcharg ::=",
 /*  46 */ "refact ::= SET NULL",
 /*  47 */ "refact ::= SET DEFAULT",
 /*  48 */ "refact ::= CASCADE",
 /*  49 */ "refact ::= RESTRICT",
 /*  50 */ "refact ::= NO ACTION",
 /*  51 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  52 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  53 */ "init_deferred_pred_opt ::=",
 /*  54 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  55 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  56 */ "tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP",
 /*  57 */ "tcons ::= cconsname UNIQUE LP sortlist RP",
 /*  58 */ "tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /*  59 */ "defer_subclause_opt ::=",
 /*  60 */ "onconf ::=",
 /*  61 */ "onconf ::= ON CONFLICT resolvetype",
 /*  62 */ "orconf ::=",
 /*  63 */ "orconf ::= OR resolvetype",
 /*  64 */ "resolvetype ::= IGNORE",
 /*  65 */ "resolvetype ::= REPLACE",
 /*  66 */ "cmd ::= DROP TABLE ifexists fullname",
 /*  67 */ "cmd ::= DROP VIEW ifexists fullname",
 /*  68 */ "ifexists ::= IF EXISTS",
 /*  69 */ "ifexists ::=",
 /*  70 */ "cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select",
 /*  71 */ "cmd ::= select",
 /*  72 */ "select ::= with selectnowith",
 /*  73 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /*  74 */ "multiselect_op ::= UNION",
 /*  75 */ "multiselect_op ::= UNION ALL",
 /*  76 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /*  77 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /*  78 */ "values ::= VALUES LP nexprlist RP",
 /*  79 */ "values ::= values COMMA LP exprlist RP",
 /*  80 */ "distinct ::= DISTINCT",
 /*  81 */ "distinct ::= ALL",
 /*  82 */ "distinct ::=",
 /*  83 */ "sclp ::=",
 /*  84 */ "selcollist ::= sclp expr as",
 /*  85 */ "selcollist ::= sclp STAR",
 /*  86 */ "selcollist ::= sclp nm DOT STAR",
 /*  87 */ "as ::= AS nm",
 /*  88 */ "as ::=",
 /*  89 */ "from ::=",
 /*  90 */ "from ::= FROM seltablist",
 /*  91 */ "stl_prefix ::= seltablist joinop",
 /*  92 */ "stl_prefix ::=",
 /*  93 */ "seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt",
 /*  94 */ "seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt",
 /*  95 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /*  96 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /*  97 */ "fullname ::= nm",
 /*  98 */ "joinop ::= COMMA|JOIN",
 /*  99 */ "joinop ::= JOIN_KW JOIN",
 /* 100 */ "joinop ::= JOIN_KW join_nm JOIN",
 /* 101 */ "joinop ::= JOIN_KW join_nm join_nm JOIN",
 /* 102 */ "on_opt ::= ON expr",
 /* 103 */ "on_opt ::=",
 /* 104 */ "indexed_opt ::=",
 /* 105 */ "indexed_opt ::= INDEXED BY nm",
 /* 106 */ "indexed_opt ::= NOT INDEXED",
 /* 107 */ "using_opt ::= USING LP idlist RP",
 /* 108 */ "using_opt ::=",
 /* 109 */ "orderby_opt ::=",
 /* 110 */ "orderby_opt ::= ORDER BY sortlist",
 /* 111 */ "sortlist ::= sortlist COMMA expr sortorder",
 /* 112 */ "sortlist ::= expr sortorder",
 /* 113 */ "col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc",
 /* 114 */ "col_list_with_autoinc ::= expr autoinc",
 /* 115 */ "enable ::= ENABLE",
 /* 116 */ "enable ::= DISABLE",
 /* 117 */ "sortorder ::= ASC",
 /* 118 */ "sortorder ::= DESC",
 /* 119 */ "sortorder ::=",
 /* 120 */ "groupby_opt ::=",
 /* 121 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 122 */ "having_opt ::=",
 /* 123 */ "having_opt ::= HAVING expr",
 /* 124 */ "limit_opt ::=",
 /* 125 */ "limit_opt ::= LIMIT expr",
 /* 126 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 127 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 128 */ "cmd ::= with DELETE FROM fullname indexed_opt where_opt",
 /* 129 */ "cmd ::= TRUNCATE TABLE fullname",
 /* 130 */ "where_opt ::=",
 /* 131 */ "where_opt ::= WHERE expr",
 /* 132 */ "cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 133 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 134 */ "setlist ::= setlist COMMA LP idlist RP EQ expr",
 /* 135 */ "setlist ::= nm EQ expr",
 /* 136 */ "setlist ::= LP idlist RP EQ expr",
 /* 137 */ "cmd ::= with insert_cmd INTO fullname idlist_opt select",
 /* 138 */ "cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES",
 /* 139 */ "insert_cmd ::= INSERT orconf",
 /* 140 */ "insert_cmd ::= REPLACE",
 /* 141 */ "idlist_opt ::=",
 /* 142 */ "idlist_opt ::= LP idlist RP",
 /* 143 */ "idlist ::= idlist COMMA nm",
 /* 144 */ "idlist ::= nm",
 /* 145 */ "expr ::= LP expr RP",
 /* 146 */ "term ::= NULL",
 /* 147 */ "expr ::= ID|INDEXED",
 /* 148 */ "expr ::= JOIN_KW",
 /* 149 */ "expr ::= nm DOT nm",
 /* 150 */ "term ::= FLOAT|BLOB",
 /* 151 */ "term ::= STRING",
 /* 152 */ "term ::= FALSE",
 /* 153 */ "term ::= TRUE",
 /* 154 */ "term ::= UNKNOWN",
 /* 155 */ "term ::= INTEGER",
 /* 156 */ "expr ::= VARIABLE",
 /* 157 */ "expr ::= expr COLLATE ID|INDEXED",
 /* 158 */ "expr ::= CAST LP expr AS typedef RP",
 /* 159 */ "expr ::= TRIM LP trim_operands RP",
 /* 160 */ "trim_operands ::= trim_specification expr FROM expr",
 /* 161 */ "trim_operands ::= trim_specification FROM expr",
 /* 162 */ "trim_operands ::= expr FROM expr",
 /* 163 */ "trim_operands ::= expr",
 /* 164 */ "expr_optional ::=",
 /* 165 */ "expr_optional ::= expr",
 /* 166 */ "trim_specification ::= LEADING",
 /* 167 */ "trim_specification ::= TRAILING",
 /* 168 */ "trim_specification ::= BOTH",
 /* 169 */ "expr ::= ID|INDEXED LP distinct exprlist RP",
 /* 170 */ "expr ::= type_func LP distinct exprlist RP",
 /* 171 */ "expr ::= ID|INDEXED LP STAR RP",
 /* 172 */ "expr ::= LP nexprlist COMMA expr RP",
 /* 173 */ "expr ::= expr AND expr",
 /* 174 */ "expr ::= expr OR expr",
 /* 175 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 176 */ "expr ::= expr EQ|NE expr",
 /* 177 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 178 */ "expr ::= expr PLUS|MINUS expr",
 /* 179 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 180 */ "expr ::= expr CONCAT expr",
 /* 181 */ "likeop ::= LIKE_KW|MATCH",
 /* 182 */ "likeop ::= NOT LIKE_KW|MATCH",
 /* 183 */ "expr ::= expr likeop expr",
 /* 184 */ "expr ::= expr likeop expr ESCAPE expr",
 /* 185 */ "expr ::= expr IS NULL",
 /* 186 */ "expr ::= expr IS NOT NULL",
 /* 187 */ "expr ::= NOT expr",
 /* 188 */ "expr ::= BITNOT expr",
 /* 189 */ "expr ::= MINUS expr",
 /* 190 */ "expr ::= PLUS expr",
 /* 191 */ "between_op ::= BETWEEN",
 /* 192 */ "between_op ::= NOT BETWEEN",
 /* 193 */ "expr ::= expr between_op expr AND expr",
 /* 194 */ "in_op ::= IN",
 /* 195 */ "in_op ::= NOT IN",
 /* 196 */ "expr ::= expr in_op LP exprlist RP",
 /* 197 */ "expr ::= LP select RP",
 /* 198 */ "expr ::= expr in_op LP select RP",
 /* 199 */ "expr ::= expr in_op nm paren_exprlist",
 /* 200 */ "expr ::= EXISTS LP select RP",
 /* 201 */ "expr ::= CASE expr_optional case_exprlist case_else END",
 /* 202 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 203 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 204 */ "case_else ::= ELSE expr",
 /* 205 */ "case_else ::=",
 /* 206 */ "exprlist ::=",
 /* 207 */ "nexprlist ::= nexprlist COMMA expr",
 /* 208 */ "nexprlist ::= expr",
 /* 209 */ "paren_exprlist ::=",
 /* 210 */ "paren_exprlist ::= LP exprlist RP",
 /* 211 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP",
 /* 212 */ "uniqueflag ::= UNIQUE",
 /* 213 */ "uniqueflag ::=",
 /* 214 */ "eidlist_opt ::=",
 /* 215 */ "eidlist_opt ::= LP eidlist RP",
 /* 216 */ "eidlist ::= eidlist COMMA nm",
 /* 217 */ "eidlist ::= nm",
 /* 218 */ "cmd ::= DROP INDEX ifexists nm ON fullname",
 /* 219 */ "cmd ::= SET SESSION nm EQ term",
 /* 220 */ "cmd ::= PRAGMA nm",
 /* 221 */ "cmd ::= PRAGMA nm LP nm RP",
 /* 222 */ "cmd ::= PRAGMA nm LP nm DOT nm RP",
 /* 223 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 224 */ "trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 225 */ "trigger_time ::= BEFORE",
 /* 226 */ "trigger_time ::= AFTER",
 /* 227 */ "trigger_time ::= INSTEAD OF",
 /* 228 */ "trigger_time ::=",
 /* 229 */ "trigger_event ::= DELETE|INSERT",
 /* 230 */ "trigger_event ::= UPDATE",
 /* 231 */ "trigger_event ::= UPDATE OF idlist",
 /* 232 */ "foreach_clause ::=",
 /* 233 */ "when_clause ::=",
 /* 234 */ "when_clause ::= WHEN expr",
 /* 235 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 236 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 237 */ "trnm ::= nm DOT nm",
 /* 238 */ "tridxby ::= INDEXED BY nm",
 /* 239 */ "tridxby ::= NOT INDEXED",
 /* 240 */ "trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt",
 /* 241 */ "trigger_cmd ::= insert_cmd INTO trnm idlist_opt select",
 /* 242 */ "trigger_cmd ::= DELETE FROM trnm tridxby where_opt",
 /* 243 */ "trigger_cmd ::= select",
 /* 244 */ "expr ::= RAISE LP IGNORE RP",
 /* 245 */ "expr ::= RAISE LP raisetype COMMA STRING RP",
 /* 246 */ "raisetype ::= ROLLBACK",
 /* 247 */ "raisetype ::= ABORT",
 /* 248 */ "raisetype ::= FAIL",
 /* 249 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 250 */ "alter_table_start ::= ALTER TABLE fullname",
 /* 251 */ "alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm",
 /* 252 */ "alter_add_column ::= alter_table_start ADD column_name",
 /* 253 */ "column_name ::= COLUMN nm",
 /* 254 */ "column_name ::= nm",
 /* 255 */ "alter_column_def ::= alter_add_column typedef",
 /* 256 */ "cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /* 257 */ "cmd ::= alter_add_constraint CHECK LP expr RP",
 /* 258 */ "cmd ::= alter_add_constraint unique_spec LP sortlist RP",
 /* 259 */ "unique_spec ::= UNIQUE",
 /* 260 */ "unique_spec ::= PRIMARY KEY",
 /* 261 */ "cmd ::= alter_table_start RENAME TO nm",
 /* 262 */ "cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm",
 /* 263 */ "cmd ::= alter_table_start enable CHECK CONSTRAINT nm",
 /* 264 */ "with ::=",
 /* 265 */ "with ::= WITH wqlist",
 /* 266 */ "with ::= WITH RECURSIVE wqlist",
 /* 267 */ "wqlist ::= nm eidlist_opt AS LP select RP",
 /* 268 */ "wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP",
 /* 269 */ "typedef ::= TEXT",
 /* 270 */ "typedef ::= STRING_KW",
 /* 271 */ "typedef ::= SCALAR",
 /* 272 */ "typedef ::= BOOL",
 /* 273 */ "typedef ::= BOOLEAN",
 /* 274 */ "typedef ::= VARBINARY",
 /* 275 */ "typedef ::= UUID",
 /* 276 */ "char_len ::= LP INTEGER RP",
 /* 277 */ "typedef ::= VARCHAR char_len",
 /* 278 */ "number_typedef ::= NUMBER",
 /* 279 */ "number_typedef ::= DOUBLE",
 /* 280 */ "number_typedef ::= INT|INTEGER_KW",
 /* 281 */ "number_typedef ::= UNSIGNED",
 /* 282 */ "number_typedef ::= DECIMAL",
 /* 283 */ "input ::= ecmd",
 /* 284 */ "explain ::=",
 /* 285 */ "cmdx ::= cmd",
 /* 286 */ "savepoint_opt ::= SAVEPOINT",
 /* 287 */ "savepoint_opt ::=",
 /* 288 */ "cmd ::= create_table create_table_args with_opts create_table_end",
 /* 289 */ "create_table_args ::= LP columnlist RP",
 /* 290 */ "with_opts ::= WITH engine_opts",
 /* 291 */ "with_opts ::=",
 /* 292 */ "columnlist ::= columnlist COMMA tcons",
 /* 293 */ "columnlist ::= columnlist COMMA column_def create_column_end",
 /* 294 */ "columnlist ::= column_def create_column_end",
 /* 295 */ "column_def ::= column_name_and_type carglist",
 /* 296 */ "columnlist ::= tcons",
 /* 297 */ "carglist ::= carglist ccons",
 /* 298 */ "carglist ::=",
 /* 299 */ "ccons ::= check_constraint_def",
 /* 300 */ "tcons ::= check_constraint_def",
 /* 301 */ "defer_subclause_opt ::= defer_subclause",
 /* 302 */ "resolvetype ::= raisetype",
 /* 303 */ "selectnowith ::= oneselect",
 /* 304 */ "oneselect ::= values",
 /* 305 */ "sclp ::= selcollist COMMA",
 /* 306 */ "as ::= ID|STRING",
 /* 307 */ "join_nm ::= ID|INDEXED",
 /* 308 */ "join_nm ::= JOIN_KW",
 /* 309 */ "expr ::= term",
 /* 310 */ "type_func ::= CHAR",
 /* 311 */ "exprlist ::= nexprlist",
 /* 312 */ "foreach_clause ::= FOR EACH ROW",
 /* 313 */ "trnm ::= nm",
 /* 314 */ "tridxby ::=",
 /* 315 */ "cmd ::= alter_column_def carglist create_column_end",
 /* 316 */ "typedef ::= number_typedef",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to sqlParserAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlParser and sqlParserFree.
*/
void *sqlParserAlloc(void *(*mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
    pParser->is_fallback_failed = false;
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
    case 188: /* term */
    case 189: /* expr */
{
#line 962 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy82).pExpr, false);
#line 1604 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
}
      break;
    case 193: /* eidlist_opt */
    case 201: /* col_list_with_autoinc */
    case 202: /* sortlist */
    case 203: /* eidlist */
    case 217: /* selcollist */
    case 220: /* groupby_opt */
    case 222: /* orderby_opt */
    case 225: /* nexprlist */
    case 226: /* exprlist */
    case 227: /* sclp */
    case 238: /* setlist */
    case 248: /* paren_exprlist */
    case 249: /* case_exprlist */
{
#line 1518 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy142));
#line 1623 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
}
      break;
    case 210: /* fullname */
    case 218: /* from */
    case 229: /* seltablist */
    case 230: /* stl_prefix */
{
#line 711 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
sqlSrcListDelete(pParse->db, (yypminor->yy367));
#line 1633 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
}
      break;
    case 211: /* select */
    case 212: /* selectnowith */
    case 213: /* oneselect */
    case 224: /* values */
{
#line 473 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
sql_select_delete(pParse->db, (yypminor->yy99));
#line 1643 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
}
      break;
    case 214: /* with */
    case 267: /* wqlist */
{
#line 1816 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
sqlWithDelete(pParse->db, (yypminor->yy91));
#line 1651 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
}
      break;
    case 219: /* where_opt */
    case 221: /* having_opt */
    case 233: /* on_opt */
    case 250: /* case_else */
    case 257: /* when_clause */
{
#line 871 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy422), false);
#line 1662 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
}
      break;
    case 234: /* using_opt */
    case 236: /* idlist */
    case 240: /* idlist_opt */
{
#line 754 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy420));
#line 1671 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
}
      break;
    case 241: /* trim_operands */
{
#line 1133 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy3));
#line 1678 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
}
      break;
    case 243: /* expr_optional */
{
#line 1166 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy299), false);
#line 1685 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
}
      break;
    case 253: /* trigger_cmd_list */
    case 258: /* trigger_cmd */
{
#line 1617 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
sqlDeleteTriggerStep(pParse->db, (yypminor->yy527));
#line 1693 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
}
      break;
    case 255: /* trigger_event */
{
#line 1598 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy450).b);
#line 1700 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void sqlParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback = -1;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      } else if ( iFallback==0 ) {
        pParser->is_fallback_failed = true;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   sqlParserARG_FETCH;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
#line 44 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"

  diag_set(ClientError, ER_SQL_STACK_OVERFLOW);
  pParse->is_aborted = true;
#line 1876 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
/******** End %stack_overflow code ********************************************/
   sqlParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  sqlParserTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yypParser->yytos--;
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yypParser->yytos--;
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 165, 3 },
  { 165, 1 },
  { 166, 1 },
  { 166, 3 },
  { 168, 2 },
  { 168, 1 },
  { 168, 1 },
  { 168, 2 },
  { 168, 3 },
  { 168, 4 },
  { 171, 4 },
  { 175, 1 },
  { 176, 0 },
  { 176, 3 },
  { 178, 3 },
  { 174, 0 },
  { 182, 2 },
  { 181, 1 },
  { 170, 1 },
  { 187, 2 },
  { 187, 0 },
  { 186, 2 },
  { 186, 4 },
  { 186, 3 },
  { 186, 3 },
  { 186, 2 },
  { 186, 3 },
  { 186, 4 },
  { 186, 2 },
  { 192, 5 },
  { 186, 6 },
  { 186, 1 },
  { 186, 2 },
  { 185, 0 },
  { 185, 1 },
  { 195, 1 },
  { 195, 1 },
  { 195, 2 },
  { 195, 2 },
  { 195, 0 },
  { 197, 3 },
  { 198, 3 },
  { 194, 2 },
  { 194, 2 },
  { 194, 2 },
  { 194, 0 },
  { 199, 2 },
  { 199, 2 },
  { 199, 1 },
  { 199, 1 },
  { 199, 2 },
  { 196, 3 },
  { 196, 2 },
  { 200, 0 },
  { 200, 2 },
  { 200, 2 },
  { 179, 6 },
  { 179, 5 },
  { 179, 12 },
  { 204, 0 },
  { 190, 0 },
  { 190, 3 },
  { 206, 0 },
  { 206, 2 },
  { 207, 1 },
  { 207, 1 },
  { 168, 4 },
  { 168, 4 },
  { 209, 2 },
  { 209, 0 },
  { 168, 7 },
  { 168, 1 },
  { 211, 2 },
  { 212, 3 },
  { 215, 1 },
  { 215, 2 },
  { 215, 1 },
  { 213, 9 },
  { 224, 4 },
  { 224, 5 },
  { 216, 1 },
  { 216, 1 },
  { 216, 0 },
  { 227, 0 },
  { 217, 3 },
  { 217, 2 },
  { 217, 4 },
  { 228, 2 },
  { 228, 0 },
  { 218, 0 },
  { 218, 2 },
  { 230, 2 },
  { 230, 0 },
  { 229, 6 },
  { 229, 8 },
  { 229, 7 },
  { 229, 7 },
  { 210, 1 },
  { 231, 1 },
  { 231, 2 },
  { 231, 3 },
  { 231, 4 },
  { 233, 2 },
  { 233, 0 },
  { 232, 0 },
  { 232, 3 },
  { 232, 2 },
  { 234, 4 },
  { 234, 0 },
  { 222, 0 },
  { 222, 3 },
  { 202, 4 },
  { 202, 2 },
  { 201, 4 },
  { 201, 2 },
  { 237, 1 },
  { 237, 1 },
  { 191, 1 },
  { 191, 1 },
  { 191, 0 },
  { 220, 0 },
  { 220, 3 },
  { 221, 0 },
  { 221, 2 },
  { 223, 0 },
  { 223, 2 },
  { 223, 4 },
  { 223, 4 },
  { 168, 6 },
  { 168, 3 },
  { 219, 0 },
  { 219, 2 },
  { 168, 8 },
  { 238, 5 },
  { 238, 7 },
  { 238, 3 },
  { 238, 5 },
  { 168, 6 },
  { 168, 7 },
  { 239, 2 },
  { 239, 1 },
  { 240, 0 },
  { 240, 3 },
  { 236, 3 },
  { 236, 1 },
  { 189, 3 },
  { 188, 1 },
  { 189, 1 },
  { 189, 1 },
  { 189, 3 },
  { 188, 1 },
  { 188, 1 },
  { 188, 1 },
  { 188, 1 },
  { 188, 1 },
  { 188, 1 },
  { 189, 1 },
  { 189, 3 },
  { 189, 6 },
  { 189, 4 },
  { 241, 4 },
  { 241, 3 },
  { 241, 3 },
  { 241, 1 },
  { 243, 0 },
  { 243, 1 },
  { 242, 1 },
  { 242, 1 },
  { 242, 1 },
  { 189, 5 },
  { 189, 5 },
  { 189, 4 },
  { 189, 5 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 189, 3 },
  { 245, 1 },
  { 245, 2 },
  { 189, 3 },
  { 189, 5 },
  { 189, 3 },
  { 189, 4 },
  { 189, 2 },
  { 189, 2 },
  { 189, 2 },
  { 189, 2 },
  { 246, 1 },
  { 246, 2 },
  { 189, 5 },
  { 247, 1 },
  { 247, 2 },
  { 189, 5 },
  { 189, 3 },
  { 189, 5 },
  { 189, 4 },
  { 189, 4 },
  { 189, 5 },
  { 249, 5 },
  { 249, 4 },
  { 250, 2 },
  { 250, 0 },
  { 226, 0 },
  { 225, 3 },
  { 225, 1 },
  { 248, 0 },
  { 248, 3 },
  { 168, 10 },
  { 251, 1 },
  { 251, 0 },
  { 193, 0 },
  { 193, 3 },
  { 203, 3 },
  { 203, 1 },
  { 168, 6 },
  { 168, 5 },
  { 168, 2 },
  { 168, 5 },
  { 168, 7 },
  { 168, 5 },
  { 252, 9 },
  { 254, 1 },
  { 254, 1 },
  { 254, 2 },
  { 254, 0 },
  { 255, 1 },
  { 255, 1 },
  { 255, 3 },
  { 256, 0 },
  { 257, 0 },
  { 257, 2 },
  { 253, 3 },
  { 253, 2 },
  { 259, 3 },
  { 260, 3 },
  { 260, 2 },
  { 258, 7 },
  { 258, 5 },
  { 258, 5 },
  { 258, 1 },
  { 189, 4 },
  { 189, 6 },
  { 208, 1 },
  { 208, 1 },
  { 208, 1 },
  { 168, 4 },
  { 261, 3 },
  { 262, 4 },
  { 263, 3 },
  { 264, 2 },
  { 264, 1 },
  { 265, 2 },
  { 168, 12 },
  { 168, 5 },
  { 168, 5 },
  { 266, 1 },
  { 266, 2 },
  { 168, 4 },
  { 168, 6 },
  { 168, 5 },
  { 214, 0 },
  { 214, 2 },
  { 214, 3 },
  { 267, 6 },
  { 267, 8 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 184, 1 },
  { 268, 3 },
  { 184, 2 },
  { 269, 1 },
  { 269, 1 },
  { 269, 1 },
  { 269, 1 },
  { 269, 1 },
  { 164, 1 },
  { 166, 0 },
  { 167, 1 },
  { 169, 1 },
  { 169, 0 },
  { 168, 4 },
  { 172, 3 },
  { 173, 2 },
  { 173, 0 },
  { 177, 3 },
  { 177, 4 },
  { 177, 2 },
  { 180, 2 },
  { 177, 1 },
  { 183, 2 },
  { 183, 0 },
  { 186, 1 },
  { 179, 1 },
  { 204, 1 },
  { 207, 1 },
  { 212, 1 },
  { 213, 1 },
  { 227, 2 },
  { 228, 1 },
  { 235, 1 },
  { 235, 1 },
  { 189, 1 },
  { 244, 1 },
  { 226, 1 },
  { 256, 3 },
  { 259, 1 },
  { 260, 0 },
  { 168, 3 },
  { 184, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlParserARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* ecmd ::= explain cmdx SEMI */
#line 123 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
	if (!pParse->parse_only)
		sql_finish_coding(pParse);
}
#line 2336 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 1: /* ecmd ::= SEMI */
#line 127 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_STATEMENT_EMPTY);
  pParse->is_aborted = true;
}
#line 2344 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 2: /* explain ::= EXPLAIN */
#line 132 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ pParse->explain = 1; }
#line 2349 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 3: /* explain ::= EXPLAIN QUERY PLAN */
#line 133 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ pParse->explain = 2; }
#line 2354 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 4: /* cmd ::= START TRANSACTION */
#line 163 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{sql_transaction_begin(pParse);}
#line 2359 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 5: /* cmd ::= COMMIT */
#line 164 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{sql_transaction_commit(pParse);}
#line 2364 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 6: /* cmd ::= ROLLBACK */
#line 165 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{sql_transaction_rollback(pParse);}
#line 2369 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 7: /* cmd ::= SAVEPOINT nm */
#line 169 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2376 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 8: /* cmd ::= RELEASE savepoint_opt nm */
#line 172 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2383 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 9: /* cmd ::= ROLLBACK TO savepoint_opt nm */
#line 175 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2390 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 10: /* create_table ::= createkw TABLE ifnotexists nm */
#line 182 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_table_def_init(&pParse->create_table_def, &yymsp[0].minor.yy0, yymsp[-1].minor.yy112);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  pParse->create_table_def.new_space = sqlStartTable(pParse, &yymsp[0].minor.yy0);
  pParse->initiateTTrans = true;
}
#line 2401 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 11: /* createkw ::= CREATE */
#line 189 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{disableLookaside(pParse);}
#line 2406 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 12: /* ifnotexists ::= */
      case 33: /* autoinc ::= */ yytestcase(yyruleno==33);
      case 53: /* init_deferred_pred_opt ::= */ yytestcase(yyruleno==53);
      case 59: /* defer_subclause_opt ::= */ yytestcase(yyruleno==59);
      case 69: /* ifexists ::= */ yytestcase(yyruleno==69);
      case 82: /* distinct ::= */ yytestcase(yyruleno==82);
#line 192 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy112 = 0;}
#line 2416 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 13: /* ifnotexists ::= IF NOT EXISTS */
#line 193 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-2].minor.yy112 = 1;}
#line 2421 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 14: /* engine_opts ::= ENGINE EQ STRING */
#line 200 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  /* Note that specifying engine clause overwrites default engine. */
  if (yymsp[0].minor.yy0.n > ENGINE_NAME_MAX) {
    diag_set(ClientError, ER_CREATE_SPACE,
             pParse->create_table_def.new_space->def->name,
             "space engine name is too long");
    pParse->is_aborted = true;
    return;
  }
  /* Need to dequote name. */
  char *normalized_name = sql_name_from_token(pParse->db, &yymsp[0].minor.yy0);
  if (normalized_name == NULL)
    return;
  memcpy(pParse->create_table_def.new_space->def->engine_name, normalized_name,
         strlen(normalized_name) + 1);
  sqlDbFree(pParse->db, normalized_name);
}
#line 2442 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 15: /* create_table_end ::= */
#line 218 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ sqlEndTable(pParse); }
#line 2447 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 16: /* column_name_and_type ::= nm typedef */
#line 236 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, NULL, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy330);
  sql_create_column_start(pParse);
}
#line 2455 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 17: /* create_column_end ::= autoinc */
#line 241 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  uint32_t fieldno = pParse->create_column_def.space->def->field_count - 1;
  if (yymsp[0].minor.yy112 == 1 && sql_add_autoincrement(pParse, fieldno) != 0)
    return;
  if (pParse->create_table_def.new_space == NULL)
    sql_create_column_end(pParse);
}
#line 2466 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 18: /* nm ::= ID|INDEXED */
#line 283 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  if(yymsp[0].minor.yy0.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z);
    pParse->is_aborted = true;
  }
}
#line 2477 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 19: /* cconsname ::= CONSTRAINT nm */
#line 299 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy307 = yymsp[0].minor.yy0; }
#line 2482 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 20: /* cconsname ::= */
#line 300 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[1].minor.yy307 = Token_nil; }
#line 2487 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 21: /* ccons ::= DEFAULT term */
      case 23: /* ccons ::= DEFAULT PLUS term */ yytestcase(yyruleno==23);
#line 301 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[0].minor.yy82);}
#line 2493 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 22: /* ccons ::= DEFAULT LP expr RP */
#line 302 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[-1].minor.yy82);}
#line 2498 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 24: /* ccons ::= DEFAULT MINUS term */
#line 304 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  ExprSpan v;
  v.pExpr = sqlPExpr(pParse, TK_UMINUS, yymsp[0].minor.yy82.pExpr, 0);
  v.zStart = yymsp[-1].minor.yy0.z;
  v.zEnd = yymsp[0].minor.yy82.zEnd;
  sqlAddDefaultValue(pParse,&v);
}
#line 2509 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 25: /* ccons ::= NULL onconf */
#line 315 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
    sql_column_add_nullable_action(pParse, ON_CONFLICT_ACTION_NONE);
    /* Trigger nullability mismatch error if required. */
    if (yymsp[0].minor.yy112 != ON_CONFLICT_ACTION_ABORT)
        sql_column_add_nullable_action(pParse, yymsp[0].minor.yy112);
}
#line 2519 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 26: /* ccons ::= NOT NULL onconf */
#line 321 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{sql_column_add_nullable_action(pParse, yymsp[0].minor.yy112);}
#line 2524 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 27: /* ccons ::= cconsname PRIMARY KEY sortorder */
#line 322 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-3].minor.yy307, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, yymsp[0].minor.yy112, false);
  sqlAddPrimaryKey(pParse);
}
#line 2533 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 28: /* ccons ::= cconsname UNIQUE */
#line 327 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-1].minor.yy307, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2543 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 29: /* check_constraint_def ::= cconsname CHECK LP expr RP */
#line 336 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_ck_def_init(&pParse->create_ck_def, NULL, &yymsp[-4].minor.yy307, &yymsp[-1].minor.yy82);
  sql_create_check_contraint(pParse);
}
#line 2551 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 30: /* ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs */
#line 341 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-5].minor.yy307, NULL, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy142, yymsp[-1].minor.yy112, yymsp[0].minor.yy112,
                     false);
  sql_create_foreign_key(pParse);
}
#line 2560 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 31: /* ccons ::= defer_subclause */
#line 346 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{fk_constraint_change_defer_mode(pParse, yymsp[0].minor.yy112);}
#line 2565 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 32: /* ccons ::= COLLATE ID|INDEXED */
#line 347 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{sqlAddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2570 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 34: /* autoinc ::= AUTOINCR */
#line 352 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = 1;}
#line 2575 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 35: /* refargs ::= refact_update */
#line 360 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yylhsminor.yy112 = (yymsp[0].minor.yy112 << 8); }
#line 2580 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[0].minor.yy112 = yylhsminor.yy112;
        break;
      case 36: /* refargs ::= refact_delete */
#line 361 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yylhsminor.yy112 = yymsp[0].minor.yy112; }
#line 2586 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[0].minor.yy112 = yylhsminor.yy112;
        break;
      case 37: /* refargs ::= refact_delete refact_update */
#line 362 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yylhsminor.yy112 = (yymsp[0].minor.yy112 << 8) | (yymsp[-1].minor.yy112) ; }
#line 2592 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-1].minor.yy112 = yylhsminor.yy112;
        break;
      case 38: /* refargs ::= refact_update refact_delete */
#line 363 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yylhsminor.yy112 = (yymsp[-1].minor.yy112 << 8) | (yymsp[0].minor.yy112) ; }
#line 2598 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-1].minor.yy112 = yylhsminor.yy112;
        break;
      case 39: /* refargs ::= */
#line 364 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[1].minor.yy112 = 0; }
#line 2604 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 40: /* refact_update ::= ON UPDATE refact */
      case 41: /* refact_delete ::= ON DELETE refact */ yytestcase(yyruleno==41);
#line 367 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-2].minor.yy112 = yymsp[0].minor.yy112; }
#line 2610 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 42: /* matcharg ::= MATCH SIMPLE */
#line 372 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_MATCH_SIMPLE; }
#line 2615 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 43: /* matcharg ::= MATCH PARTIAL */
#line 373 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_MATCH_PARTIAL; }
#line 2620 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 44: /* matcharg ::= MATCH FULL */
#line 374 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_MATCH_FULL; }
#line 2625 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 45: /* matcharg ::= */
#line 375 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[1].minor.yy112 = FKEY_MATCH_SIMPLE; }
#line 2630 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 46: /* refact ::= SET NULL */
#line 378 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_ACTION_SET_NULL; }
#line 2635 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 47: /* refact ::= SET DEFAULT */
#line 379 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_ACTION_SET_DEFAULT; }
#line 2640 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 48: /* refact ::= CASCADE */
#line 380 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = FKEY_ACTION_CASCADE; }
#line 2645 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 49: /* refact ::= RESTRICT */
#line 381 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = FKEY_ACTION_RESTRICT; }
#line 2650 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 50: /* refact ::= NO ACTION */
#line 382 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = FKEY_NO_ACTION; }
#line 2655 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 51: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
#line 384 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-2].minor.yy112 = 0;}
#line 2660 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 52: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 63: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==63);
      case 139: /* insert_cmd ::= INSERT orconf */ yytestcase(yyruleno==139);
#line 385 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-1].minor.yy112 = yymsp[0].minor.yy112;}
#line 2667 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 54: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 68: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==68);
      case 192: /* between_op ::= NOT BETWEEN */ yytestcase(yyruleno==192);
      case 195: /* in_op ::= NOT IN */ yytestcase(yyruleno==195);
#line 388 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-1].minor.yy112 = 1;}
#line 2675 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 55: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
#line 389 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-1].minor.yy112 = 0;}
#line 2680 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 56: /* tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP */
#line 391 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-5].minor.yy307, yymsp[-1].minor.yy142,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, SORT_ORDER_ASC, false);
  sqlAddPrimaryKey(pParse);
}
#line 2689 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 57: /* tcons ::= cconsname UNIQUE LP sortlist RP */
#line 396 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy307, yymsp[-1].minor.yy142,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2699 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 58: /* tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 404 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-11].minor.yy307, yymsp[-7].minor.yy142, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy142, yymsp[-2].minor.yy112, yymsp[-1].minor.yy112, yymsp[0].minor.yy112);
  sql_create_foreign_key(pParse);
}
#line 2707 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 60: /* onconf ::= */
#line 419 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy112 = ON_CONFLICT_ACTION_ABORT;}
#line 2712 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 61: /* onconf ::= ON CONFLICT resolvetype */
#line 420 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-2].minor.yy112 = yymsp[0].minor.yy112;}
#line 2717 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 62: /* orconf ::= */
#line 421 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy112 = ON_CONFLICT_ACTION_DEFAULT;}
#line 2722 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 64: /* resolvetype ::= IGNORE */
#line 424 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = ON_CONFLICT_ACTION_IGNORE;}
#line 2727 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 65: /* resolvetype ::= REPLACE */
      case 140: /* insert_cmd ::= REPLACE */ yytestcase(yyruleno==140);
#line 425 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = ON_CONFLICT_ACTION_REPLACE;}
#line 2733 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 66: /* cmd ::= DROP TABLE ifexists fullname */
#line 430 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_table_def_init(&pParse->drop_table_def, yymsp[0].minor.yy367, &t, yymsp[-1].minor.yy112);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2743 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 67: /* cmd ::= DROP VIEW ifexists fullname */
#line 437 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_view_def_init(&pParse->drop_view_def, yymsp[0].minor.yy367, &t, yymsp[-1].minor.yy112);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2753 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 70: /* cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select */
#line 451 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  if (!pParse->parse_only) {
    create_view_def_init(&pParse->create_view_def, &yymsp[-3].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-2].minor.yy142, yymsp[0].minor.yy99, yymsp[-4].minor.yy112);
    pParse->initiateTTrans = true;
    sql_create_view(pParse);
  } else {
    sql_store_select(pParse, yymsp[0].minor.yy99);
  }
}
#line 2766 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 71: /* cmd ::= select */
#line 463 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0, 0, 0};
  if(!pParse->parse_only)
          sqlSelect(pParse, yymsp[0].minor.yy99, &dest);
  else
          sql_expr_extract_select(pParse, yymsp[0].minor.yy99);
  sql_select_delete(pParse->db, yymsp[0].minor.yy99);
}
#line 2778 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 72: /* select ::= with selectnowith */
#line 506 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  Select *p = yymsp[0].minor.yy99;
  if( p ){
    p->pWith = yymsp[-1].minor.yy91;
    parserDoubleLinkSelect(pParse, p);
  }else{
    sqlWithDelete(pParse->db, yymsp[-1].minor.yy91);
  }
  yymsp[-1].minor.yy99 = p; /*A-overwrites-W*/
}
#line 2792 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 73: /* selectnowith ::= selectnowith multiselect_op oneselect */
#line 519 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  Select *pRhs = yymsp[0].minor.yy99;
  Select *pLhs = yymsp[-2].minor.yy99;
  if( pRhs && pRhs->pPrior ){
    SrcList *pFrom;
    Token x;
    x.n = 0;
    parserDoubleLinkSelect(pParse, pRhs);
    pFrom = sqlSrcListAppendFromTerm(pParse,0,0,&x,pRhs,0,0);
    pRhs = sqlSelectNew(pParse,0,pFrom,0,0,0,0,0,0,0);
  }
  if( pRhs ){
    pRhs->op = (u8)yymsp[-1].minor.yy112;
    pRhs->pPrior = pLhs;
    if( ALWAYS(pLhs) ) pLhs->selFlags &= ~SF_MultiValue;
    pRhs->selFlags &= ~SF_MultiValue;
    if( yymsp[-1].minor.yy112!=TK_ALL ) pParse->hasCompound = 1;
  }else{
    sql_select_delete(pParse->db, pLhs);
  }
  yymsp[-2].minor.yy99 = pRhs;
}
#line 2818 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 74: /* multiselect_op ::= UNION */
      case 76: /* multiselect_op ::= EXCEPT|INTERSECT */ yytestcase(yyruleno==76);
#line 542 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = yymsp[0].major; /*A-overwrites-OP*/}
#line 2824 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 75: /* multiselect_op ::= UNION ALL */
#line 543 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-1].minor.yy112 = TK_ALL;}
#line 2829 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 77: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 547 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
#ifdef SQL_DEBUG
  Token s = yymsp[-8].minor.yy0; /*A-overwrites-S*/
#endif
  if (yymsp[0].minor.yy4.pLimit != NULL)
    sql_expr_check_sort_orders(pParse, yymsp[-1].minor.yy142);
  yymsp[-8].minor.yy99 = sqlSelectNew(pParse,yymsp[-6].minor.yy142,yymsp[-5].minor.yy367,yymsp[-4].minor.yy422,yymsp[-3].minor.yy142,yymsp[-2].minor.yy422,yymsp[-1].minor.yy142,yymsp[-7].minor.yy112,yymsp[0].minor.yy4.pLimit,yymsp[0].minor.yy4.pOffset);
#ifdef SQL_DEBUG
  /* Populate the Select.zSelName[] string that is used to help with
  ** query planner debugging, to differentiate between multiple Select
  ** objects in a complex query.
  **
  ** If the SELECT keyword is immediately followed by a C-style comment
  ** then extract the first few alphanumeric characters from within that
  ** comment to be the zSelName value.  Otherwise, the label is #N where
  ** is an integer that is incremented with each SELECT statement seen.
  */
  if( yymsp[-8].minor.yy99!=0 ){
    const char *z = s.z+6;
    int i;
    sql_snprintf(sizeof(yymsp[-8].minor.yy99->zSelName), yymsp[-8].minor.yy99->zSelName, "#%d",
                     ++pParse->nSelect);
    while( z[0]==' ' ) z++;
    if( z[0]=='/' && z[1]=='*' ){
      z += 2;
      while( z[0]==' ' ) z++;
      for(i=0; sqlIsalnum(z[i]); i++){}
      sql_snprintf(sizeof(yymsp[-8].minor.yy99->zSelName), yymsp[-8].minor.yy99->zSelName, "%.*s", i, z);
    }
  }
#endif /* SQL_DEBUG */
}
#line 2865 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 78: /* values ::= VALUES LP nexprlist RP */
#line 583 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy99 = sqlSelectNew(pParse,yymsp[-1].minor.yy142,0,0,0,0,0,SF_Values,0,0);
}
#line 2872 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 79: /* values ::= values COMMA LP exprlist RP */
#line 586 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  Select *pRight, *pLeft = yymsp[-4].minor.yy99;
  pRight = sqlSelectNew(pParse,yymsp[-1].minor.yy142,0,0,0,0,0,SF_Values|SF_MultiValue,0,0);
  if( ALWAYS(pLeft) ) pLeft->selFlags &= ~SF_MultiValue;
  if( pRight ){
    pRight->op = TK_ALL;
    pRight->pPrior = pLeft;
    yymsp[-4].minor.yy99 = pRight;
  }else{
    yymsp[-4].minor.yy99 = pLeft;
  }
}
#line 2888 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 80: /* distinct ::= DISTINCT */
#line 603 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = SF_Distinct;}
#line 2893 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 81: /* distinct ::= ALL */
#line 604 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = SF_All;}
#line 2898 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 83: /* sclp ::= */
      case 109: /* orderby_opt ::= */ yytestcase(yyruleno==109);
      case 120: /* groupby_opt ::= */ yytestcase(yyruleno==120);
      case 206: /* exprlist ::= */ yytestcase(yyruleno==206);
      case 209: /* paren_exprlist ::= */ yytestcase(yyruleno==209);
      case 214: /* eidlist_opt ::= */ yytestcase(yyruleno==214);
#line 617 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy142 = 0;}
#line 2908 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 84: /* selcollist ::= sclp expr as */
#line 618 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
   yymsp[-2].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-2].minor.yy142, yymsp[-1].minor.yy82.pExpr);
   if( yymsp[0].minor.yy0.n>0 ) sqlExprListSetName(pParse, yymsp[-2].minor.yy142, &yymsp[0].minor.yy0, 1);
   sqlExprListSetSpan(pParse,yymsp[-2].minor.yy142,&yymsp[-1].minor.yy82);
}
#line 2917 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 85: /* selcollist ::= sclp STAR */
#line 623 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_anon(pParse->db, TK_ASTERISK);
  if (p == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-1].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy142, p);
}
#line 2929 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 86: /* selcollist ::= sclp nm DOT STAR */
#line 631 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  struct Expr *pLeft = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (pLeft == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Expr *pRight = sqlPExpr(pParse, TK_ASTERISK, 0, 0);
  Expr *pDot = sqlPExpr(pParse, TK_DOT, pLeft, pRight);
  yymsp[-3].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy142, pDot);
}
#line 2943 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 87: /* as ::= AS nm */
#line 646 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-1].minor.yy0 = yymsp[0].minor.yy0;}
#line 2948 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 88: /* as ::= */
#line 648 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy0.n = 0; yymsp[1].minor.yy0.z = 0;}
#line 2953 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 89: /* from ::= */
#line 660 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy367 = sqlDbMallocZero(pParse->db, sizeof(*yymsp[1].minor.yy367));}
#line 2958 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 90: /* from ::= FROM seltablist */
#line 661 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy367 = yymsp[0].minor.yy367;
  sqlSrcListShiftJoinType(yymsp[-1].minor.yy367);
}
#line 2966 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 91: /* stl_prefix ::= seltablist joinop */
#line 669 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
   if( ALWAYS(yymsp[-1].minor.yy367 && yymsp[-1].minor.yy367->nSrc>0) ) yymsp[-1].minor.yy367->a[yymsp[-1].minor.yy367->nSrc-1].fg.jointype = (u8)yymsp[0].minor.yy112;
}
#line 2973 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 92: /* stl_prefix ::= */
#line 672 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy367 = 0;}
#line 2978 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 93: /* seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt */
#line 674 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-5].minor.yy367,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy422,yymsp[0].minor.yy420);
  sqlSrcListIndexedBy(pParse, yymsp[-5].minor.yy367, &yymsp[-2].minor.yy0);
}
#line 2986 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 94: /* seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt */
#line 679 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-7].minor.yy367,&yymsp[-6].minor.yy0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy422,yymsp[0].minor.yy420);
  sqlSrcListFuncArgs(pParse, yymsp[-7].minor.yy367, yymsp[-4].minor.yy142);
}
#line 2994 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 95: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 684 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy367,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy99,yymsp[-1].minor.yy422,yymsp[0].minor.yy420);
}
#line 3001 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 96: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 688 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  if( yymsp[-6].minor.yy367==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy422==0 && yymsp[0].minor.yy420==0 ){
    yymsp[-6].minor.yy367 = yymsp[-4].minor.yy367;
  }else if( yymsp[-4].minor.yy367->nSrc==1 ){
    yymsp[-6].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy367,0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy422,yymsp[0].minor.yy420);
    if( yymsp[-6].minor.yy367 ){
      struct SrcList_item *pNew = &yymsp[-6].minor.yy367->a[yymsp[-6].minor.yy367->nSrc-1];
      struct SrcList_item *pOld = yymsp[-4].minor.yy367->a;
      pNew->zName = pOld->zName;
      pNew->pSelect = pOld->pSelect;
      pOld->zName =  0;
      pOld->pSelect = 0;
    }
    sqlSrcListDelete(pParse->db, yymsp[-4].minor.yy367);
  }else{
    Select *pSubquery;
    sqlSrcListShiftJoinType(yymsp[-4].minor.yy367);
    pSubquery = sqlSelectNew(pParse,0,yymsp[-4].minor.yy367,0,0,0,0,SF_NestedFrom,0,0);
    yymsp[-6].minor.yy367 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy367,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy422,yymsp[0].minor.yy420);
  }
}
#line 3026 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 97: /* fullname ::= nm */
#line 712 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  /* yylhsminor.yy367-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy367 = sql_src_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy367 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3038 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[0].minor.yy367 = yylhsminor.yy367;
        break;
      case 98: /* joinop ::= COMMA|JOIN */
#line 725 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = JT_INNER; }
#line 3044 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 99: /* joinop ::= JOIN_KW JOIN */
#line 727 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-1].minor.yy112 = sqlJoinType(pParse,&yymsp[-1].minor.yy0,0,0);  /*X-overwrites-A*/}
#line 3049 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 100: /* joinop ::= JOIN_KW join_nm JOIN */
#line 729 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-2].minor.yy112 = sqlJoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); /*X-overwrites-A*/}
#line 3054 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 101: /* joinop ::= JOIN_KW join_nm join_nm JOIN */
#line 731 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-3].minor.yy112 = sqlJoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0);/*X-overwrites-A*/}
#line 3059 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 102: /* on_opt ::= ON expr */
      case 123: /* having_opt ::= HAVING expr */ yytestcase(yyruleno==123);
      case 131: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==131);
      case 204: /* case_else ::= ELSE expr */ yytestcase(yyruleno==204);
#line 735 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-1].minor.yy422 = yymsp[0].minor.yy82.pExpr;}
#line 3067 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 103: /* on_opt ::= */
      case 122: /* having_opt ::= */ yytestcase(yyruleno==122);
      case 130: /* where_opt ::= */ yytestcase(yyruleno==130);
      case 205: /* case_else ::= */ yytestcase(yyruleno==205);
#line 736 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy422 = 0;}
#line 3075 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 104: /* indexed_opt ::= */
#line 749 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy0.z=0; yymsp[1].minor.yy0.n=0;}
#line 3080 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 105: /* indexed_opt ::= INDEXED BY nm */
#line 750 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;}
#line 3085 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 106: /* indexed_opt ::= NOT INDEXED */
#line 751 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-1].minor.yy0.z=0; yymsp[-1].minor.yy0.n=1;}
#line 3090 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 107: /* using_opt ::= USING LP idlist RP */
#line 755 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-3].minor.yy420 = yymsp[-1].minor.yy420;}
#line 3095 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 108: /* using_opt ::= */
      case 141: /* idlist_opt ::= */ yytestcase(yyruleno==141);
#line 756 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy420 = 0;}
#line 3101 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 110: /* orderby_opt ::= ORDER BY sortlist */
      case 121: /* groupby_opt ::= GROUP BY nexprlist */ yytestcase(yyruleno==121);
#line 770 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-2].minor.yy142 = yymsp[0].minor.yy142;}
#line 3107 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 111: /* sortlist ::= sortlist COMMA expr sortorder */
#line 771 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy142,yymsp[-1].minor.yy82.pExpr);
  sqlExprListSetSortOrder(yymsp[-3].minor.yy142,yymsp[0].minor.yy112);
}
#line 3115 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 112: /* sortlist ::= expr sortorder */
#line 775 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  /* yylhsminor.yy142-overwrites-yymsp[-1].minor.yy82. */
  yylhsminor.yy142 = sql_expr_list_append(pParse->db,NULL,yymsp[-1].minor.yy82.pExpr);
  sqlExprListSetSortOrder(yylhsminor.yy142,yymsp[0].minor.yy112);
}
#line 3124 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-1].minor.yy142 = yylhsminor.yy142;
        break;
      case 113: /* col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc */
#line 789 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  uint32_t fieldno;
  if (yymsp[0].minor.yy112 == 1) {
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy82.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  yymsp[-3].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy142, yymsp[-1].minor.yy82.pExpr);
}
#line 3139 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 114: /* col_list_with_autoinc ::= expr autoinc */
#line 800 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  if (yymsp[0].minor.yy112 == 1) {
    uint32_t fieldno = 0;
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy82.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  /* yylhsminor.yy142-overwrites-yymsp[-1].minor.yy82. */
  yylhsminor.yy142 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy82.pExpr);
}
#line 3154 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-1].minor.yy142 = yylhsminor.yy142;
        break;
      case 115: /* enable ::= ENABLE */
#line 813 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy497 = true;}
#line 3160 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 116: /* enable ::= DISABLE */
#line 814 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy497 = false;}
#line 3165 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 117: /* sortorder ::= ASC */
#line 818 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = SORT_ORDER_ASC;}
#line 3170 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 118: /* sortorder ::= DESC */
#line 819 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = SORT_ORDER_DESC;}
#line 3175 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 119: /* sortorder ::= */
#line 820 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy112 = SORT_ORDER_UNDEF;}
#line 3180 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 124: /* limit_opt ::= */
#line 845 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy4.pLimit = 0; yymsp[1].minor.yy4.pOffset = 0;}
#line 3185 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 125: /* limit_opt ::= LIMIT expr */
#line 846 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-1].minor.yy4.pLimit = yymsp[0].minor.yy82.pExpr; yymsp[-1].minor.yy4.pOffset = 0;}
#line 3190 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 126: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 848 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-3].minor.yy4.pLimit = yymsp[-2].minor.yy82.pExpr; yymsp[-3].minor.yy4.pOffset = yymsp[0].minor.yy82.pExpr;}
#line 3195 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 127: /* limit_opt ::= LIMIT expr COMMA expr */
#line 850 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-3].minor.yy4.pOffset = yymsp[-2].minor.yy82.pExpr; yymsp[-3].minor.yy4.pLimit = yymsp[0].minor.yy82.pExpr;}
#line 3200 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 128: /* cmd ::= with DELETE FROM fullname indexed_opt where_opt */
#line 854 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy91, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-2].minor.yy367, &yymsp[-1].minor.yy0);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sql_table_delete_from(pParse,yymsp[-2].minor.yy367,yymsp[0].minor.yy422);
}
#line 3212 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 129: /* cmd ::= TRUNCATE TABLE fullname */
#line 865 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  pParse->initiateTTrans = true;
  sql_table_truncate(pParse, yymsp[0].minor.yy367);
}
#line 3220 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 132: /* cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 879 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-7].minor.yy91, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-4].minor.yy367, &yymsp[-3].minor.yy0);
  if (yymsp[-1].minor.yy142 != NULL && yymsp[-1].minor.yy142->nExpr > pParse->db->aLimit[SQL_LIMIT_COLUMN]) {
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of columns in set "\
             "list", yymsp[-1].minor.yy142->nExpr, pParse->db->aLimit[SQL_LIMIT_COLUMN]);
    pParse->is_aborted = true;
  }
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlUpdate(pParse,yymsp[-4].minor.yy367,yymsp[-1].minor.yy142,yymsp[0].minor.yy422,yymsp[-5].minor.yy112);
}
#line 3237 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 133: /* setlist ::= setlist COMMA nm EQ expr */
#line 896 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy142 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy142, yymsp[0].minor.yy82.pExpr);
  sqlExprListSetName(pParse, yymsp[-4].minor.yy142, &yymsp[-2].minor.yy0, 1);
}
#line 3245 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 134: /* setlist ::= setlist COMMA LP idlist RP EQ expr */
#line 900 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy142 = sqlExprListAppendVector(pParse, yymsp[-6].minor.yy142, yymsp[-3].minor.yy420, yymsp[0].minor.yy82.pExpr);
}
#line 3252 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 135: /* setlist ::= nm EQ expr */
#line 903 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yylhsminor.yy142 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy82.pExpr);
  sqlExprListSetName(pParse, yylhsminor.yy142, &yymsp[-2].minor.yy0, 1);
}
#line 3260 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-2].minor.yy142 = yylhsminor.yy142;
        break;
      case 136: /* setlist ::= LP idlist RP EQ expr */
#line 907 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy142 = sqlExprListAppendVector(pParse, 0, yymsp[-3].minor.yy420, yymsp[0].minor.yy82.pExpr);
}
#line 3268 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 137: /* cmd ::= with insert_cmd INTO fullname idlist_opt select */
#line 913 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy91, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-2].minor.yy367, yymsp[0].minor.yy99, yymsp[-1].minor.yy420, yymsp[-4].minor.yy112);
}
#line 3279 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 138: /* cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES */
#line 921 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-6].minor.yy91, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-3].minor.yy367, 0, yymsp[-2].minor.yy420, yymsp[-5].minor.yy112);
}
#line 3290 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 142: /* idlist_opt ::= LP idlist RP */
#line 939 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-2].minor.yy420 = yymsp[-1].minor.yy420;}
#line 3295 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 143: /* idlist ::= idlist COMMA nm */
#line 940 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy420 = sql_id_list_append(pParse->db,yymsp[-2].minor.yy420,&yymsp[0].minor.yy0);
  if (yymsp[-2].minor.yy420 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3306 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 144: /* idlist ::= nm */
#line 947 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  /* yylhsminor.yy420-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy420 = sql_id_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy420 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3318 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[0].minor.yy420 = yylhsminor.yy420;
        break;
      case 145: /* expr ::= LP expr RP */
#line 1050 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{spanSet(&yymsp[-2].minor.yy82,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/  yymsp[-2].minor.yy82.pExpr = yymsp[-1].minor.yy82.pExpr;}
#line 3324 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 146: /* term ::= NULL */
      case 150: /* term ::= FLOAT|BLOB */ yytestcase(yyruleno==150);
      case 151: /* term ::= STRING */ yytestcase(yyruleno==151);
      case 152: /* term ::= FALSE */ yytestcase(yyruleno==152);
      case 153: /* term ::= TRUE */ yytestcase(yyruleno==153);
      case 154: /* term ::= UNKNOWN */ yytestcase(yyruleno==154);
#line 1051 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy82,pParse,yymsp[0].major,yymsp[0].minor.yy0);/*A-overwrites-X*/}
#line 3334 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 147: /* expr ::= ID|INDEXED */
      case 148: /* expr ::= JOIN_KW */ yytestcase(yyruleno==148);
#line 1052 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy82,pParse,TK_ID,yymsp[0].minor.yy0); /*A-overwrites-X*/}
#line 3340 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 149: /* expr ::= nm DOT nm */
#line 1054 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  struct Expr *temp1 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (temp1 == NULL) {
    pParse->is_aborted = true;
    return;
  }
  struct Expr *temp2 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[0].minor.yy0);
  if (temp2 == NULL) {
    sql_expr_delete(pParse->db, temp1, false);
    pParse->is_aborted = true;
    return;
  }
  spanSet(&yymsp[-2].minor.yy82,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-2].minor.yy82.pExpr = sqlPExpr(pParse, TK_DOT, temp1, temp2);
}
#line 3359 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 155: /* term ::= INTEGER */
#line 1075 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yylhsminor.yy82.pExpr = sql_expr_new_dequoted(pParse->db, TK_INTEGER, &yymsp[0].minor.yy0);
  if (yylhsminor.yy82.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yylhsminor.yy82.pExpr->type = FIELD_TYPE_INTEGER;
  yylhsminor.yy82.zStart = yymsp[0].minor.yy0.z;
  yylhsminor.yy82.zEnd = yymsp[0].minor.yy0.z + yymsp[0].minor.yy0.n;
  if( yylhsminor.yy82.pExpr ) yylhsminor.yy82.pExpr->flags |= EP_Leaf;
}
#line 3374 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[0].minor.yy82 = yylhsminor.yy82;
        break;
      case 156: /* expr ::= VARIABLE */
#line 1086 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  Token t = yymsp[0].minor.yy0;
  if (pParse->parse_only) {
    spanSet(&yylhsminor.yy82, &t, &t);
    diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
             pParse->line_pos, "bindings are not allowed in DDL");
    pParse->is_aborted = true;
    yylhsminor.yy82.pExpr = NULL;
  } else if (!(yymsp[0].minor.yy0.z[0]=='#' && sqlIsdigit(yymsp[0].minor.yy0.z[1]))) {
    u32 n = yymsp[0].minor.yy0.n;
    spanExpr(&yylhsminor.yy82, pParse, TK_VARIABLE, yymsp[0].minor.yy0);
    if (yylhsminor.yy82.pExpr->u.zToken[0] == '?' && n > 1) {
      diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
      pParse->is_aborted = true;
    } else {
      sqlExprAssignVarNumber(pParse, yylhsminor.yy82.pExpr, n);
    }
  }else{
    assert( t.n>=2 );
    spanSet(&yylhsminor.yy82, &t, &t);
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
    pParse->is_aborted = true;
    yylhsminor.yy82.pExpr = NULL;
  }
}
#line 3404 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[0].minor.yy82 = yylhsminor.yy82;
        break;
      case 157: /* expr ::= expr COLLATE ID|INDEXED */
#line 1111 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy82.pExpr = sqlExprAddCollateToken(pParse, yymsp[-2].minor.yy82.pExpr, &yymsp[0].minor.yy0, 1);
  yymsp[-2].minor.yy82.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3413 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 158: /* expr ::= CAST LP expr AS typedef RP */
#line 1116 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy82,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-5].minor.yy82.pExpr = sql_expr_new_dequoted(pParse->db, TK_CAST, NULL);
  if (yymsp[-5].minor.yy82.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy82.pExpr->type = yymsp[-1].minor.yy330.type;
  sqlExprAttachSubtrees(pParse->db, yymsp[-5].minor.yy82.pExpr, yymsp[-3].minor.yy82.pExpr, 0);
}
#line 3427 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 159: /* expr ::= TRIM LP trim_operands RP */
#line 1127 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yylhsminor.yy82.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy3, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy82, &yymsp[-3].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3435 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-3].minor.yy82 = yylhsminor.yy82;
        break;
      case 160: /* trim_operands ::= trim_specification expr FROM expr */
#line 1135 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy82.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-3].minor.yy385]);
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, yylhsminor.yy3, p);
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, yylhsminor.yy3, yymsp[-2].minor.yy82.pExpr);
}
#line 3447 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-3].minor.yy3 = yylhsminor.yy3;
        break;
      case 161: /* trim_operands ::= trim_specification FROM expr */
#line 1143 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy82.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-2].minor.yy385]);
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, yylhsminor.yy3, p);
}
#line 3458 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-2].minor.yy3 = yylhsminor.yy3;
        break;
      case 162: /* trim_operands ::= expr FROM expr */
#line 1150 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy82.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[TRIM_BOTH]);
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, yylhsminor.yy3, p);
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, yylhsminor.yy3, yymsp[-2].minor.yy82.pExpr);
}
#line 3470 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-2].minor.yy3 = yylhsminor.yy3;
        break;
      case 163: /* trim_operands ::= expr */
#line 1158 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy82.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[TRIM_BOTH]);
  yylhsminor.yy3 = sql_expr_list_append(pParse->db, yylhsminor.yy3, p);
}
#line 3481 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[0].minor.yy3 = yylhsminor.yy3;
        break;
      case 164: /* expr_optional ::= */
#line 1168 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[1].minor.yy299 = NULL; }
#line 3487 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 165: /* expr_optional ::= expr */
#line 1169 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yylhsminor.yy299 = yymsp[0].minor.yy82.pExpr; }
#line 3492 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[0].minor.yy299 = yylhsminor.yy299;
        break;
      case 166: /* trim_specification ::= LEADING */
#line 1173 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy385 = TRIM_LEADING; }
#line 3498 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 167: /* trim_specification ::= TRAILING */
#line 1174 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy385 = TRIM_TRAILING; }
#line 3503 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 168: /* trim_specification ::= BOTH */
#line 1175 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy385 = TRIM_BOTH; }
#line 3508 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 169: /* expr ::= ID|INDEXED LP distinct exprlist RP */
      case 170: /* expr ::= type_func LP distinct exprlist RP */ yytestcase(yyruleno==170);
#line 1177 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy142 && yymsp[-1].minor.yy142->nExpr>pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG] ){
    const char *err =
      tt_sprintf("Number of arguments to function %.*s", yymsp[-4].minor.yy0.n, yymsp[-4].minor.yy0.z);
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, err, yymsp[-1].minor.yy142->nExpr,
             pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG]);
    pParse->is_aborted = true;
  }
  yylhsminor.yy82.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy142, &yymsp[-4].minor.yy0);
  spanSet(&yylhsminor.yy82,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy112==SF_Distinct && yylhsminor.yy82.pExpr ){
    yylhsminor.yy82.pExpr->flags |= EP_Distinct;
  }
}
#line 3527 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-4].minor.yy82 = yylhsminor.yy82;
        break;
      case 171: /* expr ::= ID|INDEXED LP STAR RP */
#line 1212 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yylhsminor.yy82.pExpr = sqlExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy82,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 3536 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-3].minor.yy82 = yylhsminor.yy82;
        break;
      case 172: /* expr ::= LP nexprlist COMMA expr RP */
#line 1247 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy142, yymsp[-1].minor.yy82.pExpr);
  yylhsminor.yy82.pExpr = sqlPExpr(pParse, TK_VECTOR, 0, 0);
  if( yylhsminor.yy82.pExpr ){
    yylhsminor.yy82.pExpr->x.pList = pList;
    spanSet(&yylhsminor.yy82, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
  }else{
    sql_expr_list_delete(pParse->db, pList);
  }
}
#line 3551 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-4].minor.yy82 = yylhsminor.yy82;
        break;
      case 173: /* expr ::= expr AND expr */
      case 174: /* expr ::= expr OR expr */ yytestcase(yyruleno==174);
      case 175: /* expr ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==175);
      case 176: /* expr ::= expr EQ|NE expr */ yytestcase(yyruleno==176);
      case 177: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==177);
      case 178: /* expr ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==178);
      case 179: /* expr ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==179);
      case 180: /* expr ::= expr CONCAT expr */ yytestcase(yyruleno==180);
#line 1258 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{spanBinaryExpr(pParse,yymsp[-1].major,&yymsp[-2].minor.yy82,&yymsp[0].minor.yy82);}
#line 3564 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 181: /* likeop ::= LIKE_KW|MATCH */
#line 1271 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy0=yymsp[0].minor.yy0;/*A-overwrites-X*/}
#line 3569 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 182: /* likeop ::= NOT LIKE_KW|MATCH */
#line 1272 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-1].minor.yy0=yymsp[0].minor.yy0; yymsp[-1].minor.yy0.n|=0x80000000; /*yymsp[-1].minor.yy0-overwrite-yymsp[0].minor.yy0*/}
#line 3574 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 183: /* expr ::= expr likeop expr */
#line 1273 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-1].minor.yy0.n & 0x80000000;
  yymsp[-1].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[0].minor.yy82.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-2].minor.yy82.pExpr);
  yymsp[-2].minor.yy82.pExpr = sqlExprFunction(pParse, pList, &yymsp[-1].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-2].minor.yy82);
  yymsp[-2].minor.yy82.zEnd = yymsp[0].minor.yy82.zEnd;
  if( yymsp[-2].minor.yy82.pExpr ) yymsp[-2].minor.yy82.pExpr->flags |= EP_InfixFunc;
}
#line 3589 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 184: /* expr ::= expr likeop expr ESCAPE expr */
#line 1284 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-3].minor.yy0.n & 0x80000000;
  yymsp[-3].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy82.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-4].minor.yy82.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy82.pExpr);
  yymsp[-4].minor.yy82.pExpr = sqlExprFunction(pParse, pList, &yymsp[-3].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-4].minor.yy82);
  yymsp[-4].minor.yy82.zEnd = yymsp[0].minor.yy82.zEnd;
  if( yymsp[-4].minor.yy82.pExpr ) yymsp[-4].minor.yy82.pExpr->flags |= EP_InfixFunc;
}
#line 3605 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 185: /* expr ::= expr IS NULL */
#line 1314 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_ISNULL,&yymsp[-2].minor.yy82,&yymsp[0].minor.yy0);}
#line 3610 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 186: /* expr ::= expr IS NOT NULL */
#line 1315 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_NOTNULL,&yymsp[-3].minor.yy82,&yymsp[0].minor.yy0);}
#line 3615 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 187: /* expr ::= NOT expr */
      case 188: /* expr ::= BITNOT expr */ yytestcase(yyruleno==188);
#line 1337 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy82,pParse,yymsp[-1].major,&yymsp[0].minor.yy82,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3621 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 189: /* expr ::= MINUS expr */
#line 1341 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy82,pParse,TK_UMINUS,&yymsp[0].minor.yy82,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3626 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 190: /* expr ::= PLUS expr */
#line 1343 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy82,pParse,TK_UPLUS,&yymsp[0].minor.yy82,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3631 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 191: /* between_op ::= BETWEEN */
      case 194: /* in_op ::= IN */ yytestcase(yyruleno==194);
#line 1346 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = 0;}
#line 3637 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 193: /* expr ::= expr between_op expr AND expr */
#line 1348 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy82.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy82.pExpr);
  yymsp[-4].minor.yy82.pExpr = sqlPExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy82.pExpr, 0);
  if( yymsp[-4].minor.yy82.pExpr ){
    yymsp[-4].minor.yy82.pExpr->x.pList = pList;
  }else{
    sql_expr_list_delete(pParse->db, pList);
  } 
  exprNot(pParse, yymsp[-3].minor.yy112, &yymsp[-4].minor.yy82);
  yymsp[-4].minor.yy82.zEnd = yymsp[0].minor.yy82.zEnd;
}
#line 3653 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 196: /* expr ::= expr in_op LP exprlist RP */
#line 1363 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy142==0 ){
    /* Expressions of the form
    **
    **      expr1 IN ()
    **      expr1 NOT IN ()
    **
    ** simplify to constants 0 (false) and 1 (true), respectively,
    ** regardless of the value of expr1.
    */
    sql_expr_delete(pParse->db, yymsp[-4].minor.yy82.pExpr, false);
    int tk = yymsp[-3].minor.yy112 == 0 ? TK_FALSE : TK_TRUE;
    yymsp[-4].minor.yy82.pExpr = sql_expr_new_anon(pParse->db, tk);
    if (yymsp[-4].minor.yy82.pExpr == NULL) {
      pParse->is_aborted = true;
      return;
    }
    yymsp[-4].minor.yy82.pExpr->type = FIELD_TYPE_BOOLEAN;
  }else if( yymsp[-1].minor.yy142->nExpr==1 ){
    /* Expressions of the form:
    **
    **      expr1 IN (?1)
    **      expr1 NOT IN (?2)
    **
    ** with exactly one value on the RHS can be simplified to something
    ** like this:
    **
    **      expr1 == ?1
    **      expr1 <> ?2
    */
    Expr *pRHS = yymsp[-1].minor.yy142->a[0].pExpr;
    yymsp[-1].minor.yy142->a[0].pExpr = 0;
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy142);
    yymsp[-4].minor.yy82.pExpr = sqlPExpr(pParse, yymsp[-3].minor.yy112 ? TK_NE : TK_EQ, yymsp[-4].minor.yy82.pExpr, pRHS);
  }else{
    yymsp[-4].minor.yy82.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy82.pExpr, 0);
    if( yymsp[-4].minor.yy82.pExpr ){
      yymsp[-4].minor.yy82.pExpr->x.pList = yymsp[-1].minor.yy142;
      sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy82.pExpr);
    }else{
      sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy142);
    }
    exprNot(pParse, yymsp[-3].minor.yy112, &yymsp[-4].minor.yy82);
  }
  yymsp[-4].minor.yy82.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3703 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 197: /* expr ::= LP select RP */
#line 1409 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  spanSet(&yymsp[-2].minor.yy82,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  yymsp[-2].minor.yy82.pExpr = sqlPExpr(pParse, TK_SELECT, 0, 0);
  sqlPExprAddSelect(pParse, yymsp[-2].minor.yy82.pExpr, yymsp[-1].minor.yy99);
}
#line 3712 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 198: /* expr ::= expr in_op LP select RP */
#line 1414 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy82.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy82.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-4].minor.yy82.pExpr, yymsp[-1].minor.yy99);
  exprNot(pParse, yymsp[-3].minor.yy112, &yymsp[-4].minor.yy82);
  yymsp[-4].minor.yy82.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3722 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 199: /* expr ::= expr in_op nm paren_exprlist */
#line 1420 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  struct SrcList *pSrc = sql_src_list_append(pParse->db, 0,&yymsp[-1].minor.yy0);
  if (pSrc == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Select *pSelect = sqlSelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
  if( yymsp[0].minor.yy142 )  sqlSrcListFuncArgs(pParse, pSelect ? pSrc : 0, yymsp[0].minor.yy142);
  yymsp[-3].minor.yy82.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-3].minor.yy82.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-3].minor.yy82.pExpr, pSelect);
  exprNot(pParse, yymsp[-2].minor.yy112, &yymsp[-3].minor.yy82);
  yymsp[-3].minor.yy82.zEnd = &yymsp[-1].minor.yy0.z[yymsp[-1].minor.yy0.n];
}
#line 3739 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 200: /* expr ::= EXISTS LP select RP */
#line 1433 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  Expr *p;
  spanSet(&yymsp[-3].minor.yy82,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  p = yymsp[-3].minor.yy82.pExpr = sqlPExpr(pParse, TK_EXISTS, 0, 0);
  sqlPExprAddSelect(pParse, p, yymsp[-1].minor.yy99);
}
#line 3749 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 201: /* expr ::= CASE expr_optional case_exprlist case_else END */
#line 1441 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  spanSet(&yymsp[-4].minor.yy82,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-C*/
  yymsp[-4].minor.yy82.pExpr = sqlPExpr(pParse, TK_CASE, yymsp[-3].minor.yy299, 0);
  if( yymsp[-4].minor.yy82.pExpr ){
    yymsp[-4].minor.yy82.pExpr->x.pList = yymsp[-1].minor.yy422 ? sql_expr_list_append(pParse->db,yymsp[-2].minor.yy142,yymsp[-1].minor.yy422) : yymsp[-2].minor.yy142;
    sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy82.pExpr);
  }else{
    sql_expr_list_delete(pParse->db, yymsp[-2].minor.yy142);
    sql_expr_delete(pParse->db, yymsp[-1].minor.yy422, false);
  }
}
#line 3764 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 202: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 1454 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy142, yymsp[-2].minor.yy82.pExpr);
  yymsp[-4].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy142, yymsp[0].minor.yy82.pExpr);
}
#line 3772 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 203: /* case_exprlist ::= WHEN expr THEN expr */
#line 1458 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy142 = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy82.pExpr);
  yymsp[-3].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy142, yymsp[0].minor.yy82.pExpr);
}
#line 3780 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 207: /* nexprlist ::= nexprlist COMMA expr */
#line 1475 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-2].minor.yy142 = sql_expr_list_append(pParse->db,yymsp[-2].minor.yy142,yymsp[0].minor.yy82.pExpr);}
#line 3785 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 208: /* nexprlist ::= expr */
#line 1477 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy142 = sql_expr_list_append(pParse->db,NULL,yymsp[0].minor.yy82.pExpr); /*A-overwrites-Y*/}
#line 3790 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 210: /* paren_exprlist ::= LP exprlist RP */
      case 215: /* eidlist_opt ::= LP eidlist RP */ yytestcase(yyruleno==215);
#line 1484 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-2].minor.yy142 = yymsp[-1].minor.yy142;}
#line 3796 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 211: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP */
#line 1490 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  struct SrcList *src_list = sql_src_list_append(pParse->db,0,&yymsp[-3].minor.yy0);
  if (src_list == NULL) {
    pParse->is_aborted = true;
    return;
  }
  create_index_def_init(&pParse->create_index_def, src_list, &yymsp[-5].minor.yy0, yymsp[-1].minor.yy142, yymsp[-8].minor.yy112,
                        SORT_ORDER_ASC, yymsp[-6].minor.yy112);
  pParse->initiateTTrans = true;
  sql_create_index(pParse);
}
#line 3811 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 212: /* uniqueflag ::= UNIQUE */
#line 1503 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = SQL_INDEX_TYPE_UNIQUE;}
#line 3816 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 213: /* uniqueflag ::= */
#line 1504 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy112 = SQL_INDEX_TYPE_NON_UNIQUE;}
#line 3821 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 216: /* eidlist ::= eidlist COMMA nm */
#line 1539 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy142 = parserAddExprIdListTerm(pParse, yymsp[-2].minor.yy142, &yymsp[0].minor.yy0);
}
#line 3828 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 217: /* eidlist ::= nm */
#line 1542 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[0].minor.yy142 = parserAddExprIdListTerm(pParse, 0, &yymsp[0].minor.yy0); /*A-overwrites-Y*/
}
#line 3835 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 218: /* cmd ::= DROP INDEX ifexists nm ON fullname */
#line 1549 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  drop_index_def_init(&pParse->drop_index_def, yymsp[0].minor.yy367, &yymsp[-2].minor.yy0, yymsp[-3].minor.yy112);
  pParse->initiateTTrans = true;
  sql_drop_index(pParse);
}
#line 3844 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 219: /* cmd ::= SET SESSION nm EQ term */
#line 1557 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
    sql_setting_set(pParse,&yymsp[-2].minor.yy0,yymsp[0].minor.yy82.pExpr);
}
#line 3851 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 220: /* cmd ::= PRAGMA nm */
#line 1563 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[0].minor.yy0,0,0);
}
#line 3858 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 221: /* cmd ::= PRAGMA nm LP nm RP */
#line 1566 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0);
}
#line 3865 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 222: /* cmd ::= PRAGMA nm LP nm DOT nm RP */
#line 1569 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-5].minor.yy0,&yymsp[-1].minor.yy0,&yymsp[-3].minor.yy0);
}
#line 3872 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 223: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1574 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  pParse->initiateTTrans = true;
  sql_trigger_finish(pParse, yymsp[-1].minor.yy527, &all);
}
#line 3883 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 224: /* trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1584 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_trigger_def_init(&pParse->create_trigger_def, yymsp[-2].minor.yy367, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy112, yymsp[-4].minor.yy450.a, yymsp[-4].minor.yy450.b, yymsp[0].minor.yy422,
                          yymsp[-7].minor.yy112);
  sql_trigger_begin(pParse);
  yymsp[-8].minor.yy0 = yymsp[-6].minor.yy0; /*yymsp[-8].minor.yy0-overwrites-T*/
}
#line 3893 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 225: /* trigger_time ::= BEFORE */
#line 1592 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = TK_BEFORE; }
#line 3898 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 226: /* trigger_time ::= AFTER */
#line 1593 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = TK_AFTER;  }
#line 3903 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 227: /* trigger_time ::= INSTEAD OF */
#line 1594 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = TK_INSTEAD;}
#line 3908 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 228: /* trigger_time ::= */
#line 1595 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[1].minor.yy112 = TK_BEFORE; }
#line 3913 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 229: /* trigger_event ::= DELETE|INSERT */
      case 230: /* trigger_event ::= UPDATE */ yytestcase(yyruleno==230);
#line 1599 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy450.a = yymsp[0].major; /*A-overwrites-X*/ yymsp[0].minor.yy450.b = 0;}
#line 3919 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 231: /* trigger_event ::= UPDATE OF idlist */
#line 1601 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[-2].minor.yy450.a = TK_UPDATE; yymsp[-2].minor.yy450.b = yymsp[0].minor.yy420;}
#line 3924 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 232: /* foreach_clause ::= */
#line 1603 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "FOR EACH STATEMENT triggers are not implemented, "
           "please supply FOR EACH ROW clause");
  pParse->is_aborted = true;
}
#line 3934 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 233: /* when_clause ::= */
#line 1613 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[1].minor.yy422 = 0; }
#line 3939 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 234: /* when_clause ::= WHEN expr */
#line 1614 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy422 = yymsp[0].minor.yy82.pExpr; }
#line 3944 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 235: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1618 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  assert( yymsp[-2].minor.yy527!=0 );
  yymsp[-2].minor.yy527->pLast->pNext = yymsp[-1].minor.yy527;
  yymsp[-2].minor.yy527->pLast = yymsp[-1].minor.yy527;
}
#line 3953 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 236: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1623 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ 
  assert( yymsp[-1].minor.yy527!=0 );
  yymsp[-1].minor.yy527->pLast = yymsp[-1].minor.yy527;
}
#line 3961 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 237: /* trnm ::= nm DOT nm */
#line 1634 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "qualified table names are not allowed on INSERT, "
           "UPDATE, and DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3972 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 238: /* tridxby ::= INDEXED BY nm */
#line 1647 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the INDEXED BY clause is not allowed on UPDATE "\
           "or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3982 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 239: /* tridxby ::= NOT INDEXED */
#line 1653 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the NOT INDEXED BY clause is not allowed on "\
           "UPDATE or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3992 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 240: /* trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt */
#line 1666 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
     yymsp[-6].minor.yy527 = sql_trigger_update_step(pParse->db, &yymsp[-4].minor.yy0, yymsp[-1].minor.yy142, yymsp[0].minor.yy422, yymsp[-5].minor.yy112);
     if (yymsp[-6].minor.yy527 == NULL) {
        pParse->is_aborted = true;
        return;
     }
   }
#line 4003 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 241: /* trigger_cmd ::= insert_cmd INTO trnm idlist_opt select */
#line 1675 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  /*yylhsminor.yy527-overwrites-yymsp[-4].minor.yy112. */
  yylhsminor.yy527 = sql_trigger_insert_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy420, yymsp[0].minor.yy99, yymsp[-4].minor.yy112);
  if (yylhsminor.yy527 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4015 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-4].minor.yy527 = yylhsminor.yy527;
        break;
      case 242: /* trigger_cmd ::= DELETE FROM trnm tridxby where_opt */
#line 1685 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy527 = sql_trigger_delete_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[0].minor.yy422);
  if (yymsp[-4].minor.yy527 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4027 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 243: /* trigger_cmd ::= select */
#line 1694 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  /* yylhsminor.yy527-overwrites-yymsp[0].minor.yy99. */
  yylhsminor.yy527 = sql_trigger_select_step(pParse->db, yymsp[0].minor.yy99);
  if (yylhsminor.yy527 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4039 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[0].minor.yy527 = yylhsminor.yy527;
        break;
      case 244: /* expr ::= RAISE LP IGNORE RP */
#line 1704 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  spanSet(&yymsp[-3].minor.yy82,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-3].minor.yy82.pExpr = sqlPExpr(pParse, TK_RAISE, 0, 0);
  if( yymsp[-3].minor.yy82.pExpr ){
    yymsp[-3].minor.yy82.pExpr->on_conflict_action = ON_CONFLICT_ACTION_IGNORE;
  }
}
#line 4051 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 245: /* expr ::= RAISE LP raisetype COMMA STRING RP */
#line 1711 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy82,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-5].minor.yy82.pExpr = sql_expr_new_dequoted(pParse->db, TK_RAISE, &yymsp[-1].minor.yy0);
  if(yymsp[-5].minor.yy82.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy82.pExpr->on_conflict_action = (enum on_conflict_action) yymsp[-3].minor.yy112;
}
#line 4064 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 246: /* raisetype ::= ROLLBACK */
#line 1722 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = ON_CONFLICT_ACTION_ROLLBACK;}
#line 4069 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 247: /* raisetype ::= ABORT */
#line 1723 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = ON_CONFLICT_ACTION_ABORT;}
#line 4074 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 248: /* raisetype ::= FAIL */
#line 1724 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[0].minor.yy112 = ON_CONFLICT_ACTION_FAIL;}
#line 4079 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 249: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1728 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_trigger_def_init(&pParse->drop_trigger_def, yymsp[0].minor.yy367, &t, yymsp[-1].minor.yy112);
  pParse->initiateTTrans = true;
  sql_drop_trigger(pParse);
}
#line 4089 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 250: /* alter_table_start ::= ALTER TABLE fullname */
#line 1745 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-2].minor.yy308 = yymsp[0].minor.yy367; }
#line 4094 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 251: /* alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm */
#line 1748 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
   yylhsminor.yy530.table_name = yymsp[-3].minor.yy308;
   yylhsminor.yy530.name = yymsp[0].minor.yy0;
   pParse->initiateTTrans = true;
 }
#line 4103 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-3].minor.yy530 = yylhsminor.yy530;
        break;
      case 252: /* alter_add_column ::= alter_table_start ADD column_name */
#line 1755 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yylhsminor.yy530.table_name = yymsp[-2].minor.yy308;
  yylhsminor.yy530.name = yymsp[0].minor.yy0;
  pParse->initiateTTrans = true;
}
#line 4113 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[-2].minor.yy530 = yylhsminor.yy530;
        break;
      case 253: /* column_name ::= COLUMN nm */
#line 1761 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; }
#line 4119 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 254: /* column_name ::= nm */
#line 1762 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yylhsminor.yy0 = yymsp[0].minor.yy0; }
#line 4124 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 255: /* alter_column_def ::= alter_add_column typedef */
#line 1766 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, yymsp[-1].minor.yy530.table_name, &yymsp[-1].minor.yy530.name, &yymsp[0].minor.yy330);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  sql_create_column_start(pParse);
}
#line 4135 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 256: /* cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 1774 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, yymsp[-11].minor.yy530.table_name, &yymsp[-11].minor.yy530.name, yymsp[-7].minor.yy142, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy142,
                     yymsp[-2].minor.yy112, yymsp[-1].minor.yy112, yymsp[0].minor.yy112);
  sql_create_foreign_key(pParse);
}
#line 4144 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 257: /* cmd ::= alter_add_constraint CHECK LP expr RP */
#line 1780 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
    create_ck_def_init(&pParse->create_ck_def, yymsp[-4].minor.yy530.table_name, &yymsp[-4].minor.yy530.name, &yymsp[-1].minor.yy82);
    sql_create_check_contraint(pParse);
}
#line 4152 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 258: /* cmd ::= alter_add_constraint unique_spec LP sortlist RP */
#line 1785 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, yymsp[-4].minor.yy530.table_name, &yymsp[-4].minor.yy530.name, yymsp[-1].minor.yy142, yymsp[-3].minor.yy112,
                        SORT_ORDER_ASC, false);
  sql_create_index(pParse);
}
#line 4161 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 259: /* unique_spec ::= UNIQUE */
#line 1792 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy112 = SQL_INDEX_TYPE_CONSTRAINT_UNIQUE; }
#line 4166 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 260: /* unique_spec ::= PRIMARY KEY */
#line 1793 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy112 = SQL_INDEX_TYPE_CONSTRAINT_PK; }
#line 4171 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 261: /* cmd ::= alter_table_start RENAME TO nm */
#line 1795 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
    rename_entity_def_init(&pParse->rename_entity_def, yymsp[-3].minor.yy308, &yymsp[0].minor.yy0);
    pParse->initiateTTrans = true;
    sql_alter_table_rename(pParse);
}
#line 4180 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 262: /* cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm */
#line 1801 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  drop_constraint_def_init(&pParse->drop_constraint_def, yymsp[-3].minor.yy367, &yymsp[0].minor.yy0, false);
  pParse->initiateTTrans = true;
  sql_drop_constraint(pParse);
}
#line 4189 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 263: /* cmd ::= alter_table_start enable CHECK CONSTRAINT nm */
#line 1807 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
    enable_entity_def_init(&pParse->enable_entity_def, ENTITY_TYPE_CK, yymsp[-4].minor.yy308,
                           &yymsp[0].minor.yy0, yymsp[-3].minor.yy497);
    sql_alter_ck_constraint_enable(pParse);
}
#line 4198 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 264: /* with ::= */
#line 1819 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{yymsp[1].minor.yy91 = 0;}
#line 4203 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 265: /* with ::= WITH wqlist */
#line 1820 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-1].minor.yy91 = yymsp[0].minor.yy91; }
#line 4208 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 266: /* with ::= WITH RECURSIVE wqlist */
#line 1821 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[-2].minor.yy91 = yymsp[0].minor.yy91; }
#line 4213 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 267: /* wqlist ::= nm eidlist_opt AS LP select RP */
#line 1823 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy91 = sqlWithAdd(pParse, 0, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy142, yymsp[-1].minor.yy99); /*A-overwrites-X*/
}
#line 4220 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 268: /* wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP */
#line 1826 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy91 = sqlWithAdd(pParse, yymsp[-7].minor.yy91, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy142, yymsp[-1].minor.yy99);
}
#line 4227 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 269: /* typedef ::= TEXT */
      case 270: /* typedef ::= STRING_KW */ yytestcase(yyruleno==270);
#line 1832 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_STRING; }
#line 4233 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 271: /* typedef ::= SCALAR */
#line 1834 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_SCALAR; }
#line 4238 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 272: /* typedef ::= BOOL */
      case 273: /* typedef ::= BOOLEAN */ yytestcase(yyruleno==273);
#line 1836 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_BOOLEAN; }
#line 4244 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 274: /* typedef ::= VARBINARY */
#line 1838 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_VARBINARY; }
#line 4249 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 275: /* typedef ::= UUID */
#line 1839 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_UUID; }
#line 4254 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 276: /* char_len ::= LP INTEGER RP */
#line 1851 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  (void) yymsp[-2].minor.yy112;
  (void) yymsp[-1].minor.yy0;
}
#line 4262 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 277: /* typedef ::= VARCHAR char_len */
#line 1857 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy330.type = FIELD_TYPE_STRING;
  (void) yymsp[0].minor.yy112;
}
#line 4270 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 278: /* number_typedef ::= NUMBER */
#line 1864 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_NUMBER; }
#line 4275 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 279: /* number_typedef ::= DOUBLE */
#line 1865 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_DOUBLE; }
#line 4280 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 280: /* number_typedef ::= INT|INTEGER_KW */
#line 1866 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_INTEGER; }
#line 4285 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 281: /* number_typedef ::= UNSIGNED */
#line 1867 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_UNSIGNED; }
#line 4290 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      case 282: /* number_typedef ::= DECIMAL */
#line 1868 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"
{ yymsp[0].minor.yy330.type = FIELD_TYPE_DECIMAL; }
#line 4295 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
        break;
      default:
      /* (283) input ::= ecmd */ yytestcase(yyruleno==283);
      /* (284) explain ::= */ yytestcase(yyruleno==284);
      /* (285) cmdx ::= cmd (OPTIMIZED OUT) */ assert(yyruleno!=285);
      /* (286) savepoint_opt ::= SAVEPOINT */ yytestcase(yyruleno==286);
      /* (287) savepoint_opt ::= */ yytestcase(yyruleno==287);
      /* (288) cmd ::= create_table create_table_args with_opts create_table_end */ yytestcase(yyruleno==288);
      /* (289) create_table_args ::= LP columnlist RP */ yytestcase(yyruleno==289);
      /* (290) with_opts ::= WITH engine_opts */ yytestcase(yyruleno==290);
      /* (291) with_opts ::= */ yytestcase(yyruleno==291);
      /* (292) columnlist ::= columnlist COMMA tcons */ yytestcase(yyruleno==292);
      /* (293) columnlist ::= columnlist COMMA column_def create_column_end */ yytestcase(yyruleno==293);
      /* (294) columnlist ::= column_def create_column_end */ yytestcase(yyruleno==294);
      /* (295) column_def ::= column_name_and_type carglist */ yytestcase(yyruleno==295);
      /* (296) columnlist ::= tcons (OPTIMIZED OUT) */ assert(yyruleno!=296);
      /* (297) carglist ::= carglist ccons */ yytestcase(yyruleno==297);
      /* (298) carglist ::= */ yytestcase(yyruleno==298);
      /* (299) ccons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=299);
      /* (300) tcons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=300);
      /* (301) defer_subclause_opt ::= defer_subclause (OPTIMIZED OUT) */ assert(yyruleno!=301);
      /* (302) resolvetype ::= raisetype (OPTIMIZED OUT) */ assert(yyruleno!=302);
      /* (303) selectnowith ::= oneselect (OPTIMIZED OUT) */ assert(yyruleno!=303);
      /* (304) oneselect ::= values */ yytestcase(yyruleno==304);
      /* (305) sclp ::= selcollist COMMA */ yytestcase(yyruleno==305);
      /* (306) as ::= ID|STRING */ yytestcase(yyruleno==306);
      /* (307) join_nm ::= ID|INDEXED */ yytestcase(yyruleno==307);
      /* (308) join_nm ::= JOIN_KW */ yytestcase(yyruleno==308);
      /* (309) expr ::= term (OPTIMIZED OUT) */ assert(yyruleno!=309);
      /* (310) type_func ::= CHAR */ yytestcase(yyruleno==310);
      /* (311) exprlist ::= nexprlist */ yytestcase(yyruleno==311);
      /* (312) foreach_clause ::= FOR EACH ROW */ yytestcase(yyruleno==312);
      /* (313) trnm ::= nm */ yytestcase(yyruleno==313);
      /* (314) tridxby ::= */ yytestcase(yyruleno==314);
      /* (315) cmd ::= alter_column_def carglist create_column_end */ yytestcase(yyruleno==315);
      /* (316) typedef ::= number_typedef (OPTIMIZED OUT) */ assert(yyruleno!=316);
        break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
/************ End %parse_failure code *****************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  sqlParserTOKENTYPE yyminor         /* The minor type of the error token */
){
  sqlParserARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 32 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  if (yypParser->is_fallback_failed && TOKEN.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, TOKEN.n, TOKEN.z, TOKEN.n, TOKEN.z);
  } else {
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, TOKEN.n,
             TOKEN.z);
  }
  pParse->is_aborted = true;
#line 4400 "/build/usr/src/debug/tarantool-2.10.0~beta1/src/box/sql/parse.c"
/************ End %syntax_error code ******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
  assert( yypParser->yytos==yypParser->yystack );
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
/*********** End %parse_accept code *******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlParserTOKENTYPE yyminor       /* The value for the token */
  sqlParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack
         PARSER_ERROR_CHECK);
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
  }
#endif
  return;
}
